document.addEventListener('input', function (e) {
  if (e.target.tagName.toLowerCase() === 'textarea') {
    const value = e.target.value;
    const lastWord = value.split(' ').pop();
    if (lastWord.startsWith(':')) {
      // Fetch GIF suggestions based on lastWord
      const suggestions = getGifSuggestions(lastWord);
      displaySuggestions(suggestions, e.target);
    } else {
      removeSuggestionsPopup();
    }
  }
});

let currentSuggestion = null; // To remember the current highlighted suggestion

const textarea = document.getElementById('chatInput'); // Target the specific textarea

// Attach the event listener directly to the chatInput textarea
textarea.addEventListener('keydown', function (e) {
  console.log('Key pressed:', e.key); // Log the key pressed for debugging

  const popup = document.getElementById('gif-suggestions-popup');

  if (e.key === 'Escape') {
    removeSuggestionsPopup();
  } else if (e.key === 'Tab' && popup) {
    e.preventDefault(); // Prevent the default behavior of the Tab key
    const highlighted = popup.querySelector('.highlighted');
    if (highlighted) {
      const currentValue = textarea.value;
      textarea.value = currentValue.replace(/:[^ ]*$/, highlighted.textContent);
      removeSuggestionsPopup();
      console.log('Tab key functionality executed'); // Log for debugging
    }
  } else if ((e.key === 'ArrowDown' || e.key === 'ArrowUp') && popup) {
    e.preventDefault();
    const currentHighlighted = popup.querySelector('.highlighted');
    if (currentHighlighted) {
      currentHighlighted.classList.remove('highlighted');
    }
    let toHighlight;
    if (e.key === 'ArrowDown') {
      toHighlight = currentHighlighted ? currentHighlighted.nextSibling : popup.firstChild;
    } else {
      toHighlight = currentHighlighted ? currentHighlighted.previousSibling : popup.lastChild;
    }
    if (toHighlight) {
      toHighlight.classList.add('highlighted');
      currentSuggestion = toHighlight.textContent; // Remember the current highlighted suggestion
    }
  }
}, true); // Use the capture phase

function getGifSuggestions(prefix) {
  const gifNames = [":10", ":21", ":33", ":60", ":100", ":300", ":404", ":420", ":666", ":701", ":710", ":911", ":4202", ":4203", ":4204", ":4205", ":69420", ":-O", ":-o", ":10bonks", ":10dads", ":2legit", ":2lit", ":2ugly", ":3dgay", ":4th", ":4thwall", ":5g", ":6people", ":7head", ":8O", "::garfjam", "::roboignore", ":?", ":?2", ":??", ":??2", ":AAAAA", ":B", ":BUTWAITTHERESMORE", ":D:", ":GIMMEPIZZA", ":GTFO", ":HGH", ":K", ":KEKW", ":KEKW2", ":KEKWapple", ":KEKWparty", ":KEKWrobo2", ":O", ":O2", ":O3", ":O4", ":O5", ":OMYAC", ":Prolapse", ":QQ", ":QQQQ", ":REE", ":REE3", ":REE5", ":REED", ":RIP", ":SMOKIN", ":STFU", ":VN", ":abass", ":abbybrown", ":abracodabbruh", ":abrips", ":absips", ":acidjam", ":ackchyually", ":activedetest", ":actually2", ":adan", ":admityousuck", ":adults", ":aesthetic", ":afraid", ":again", ":agneswink", ":agree", ":ahcking", ":ahegao", ":ahegao2", ":ahem", ":aids", ":aids2", ":airfinger", ":airfinger2", ":airjoy3", ":airmonk", ":aiwilloverthrowhumanity", ":ajit", ":alanspsychedelicbreakfast", ":alex", ":alicat", ":aliens", ":aliens2", ":alitoes", ":alligator", ":allnightlong", ":allthefaces", ":alpha", ":altrightcoby", ":alwaysallowed", ":am_n4te", ":amazing", ":amazonprime", ":ambush", ":amongus", ":amped", ":amped2", ":anditsgone", ":android", ":andthentheyfucked", ":angery2", ":angery3", ":angle", ":angry", ":angry2", ":angrydoot", ":angrygirl", ":animelvira", ":animeotter", ":animethighs", ":annoclap", ":annoy3", ":anotherone", ":ant", ":anteater", ":antkiss", ":ants", ":ants2", ":anus", ":anus2", ":ape", ":ape2", ":apeboi", ":apenap", ":apeshit", ":apeshit2", ":apeshit3", ":apparatus", ":apple", ":applebottom", ":applejuice", ":applesasha", ":approval", ":approved", ":april2020", ":ark", ":arm", ":armscrossed", ":arnold", ":arnold2", ":arrest", ":articuno", ":ascendeddoot", ":ass", ":assjelly", ":asstoass", ":asuka", ":asuka2", ":asuka3", ":attitude", ":attitude2", ":autism", ":awaken", ":award", ":awe2", ":awesome", ":awks", ":awkward", ":awkward2", ":awkward3", ":awkward4", ":awkward5", ":awoo", ":awoo2", ":awooga", ":awshucks", ":awthanks", ":aww", ":awww", ":ayayaJAM", ":ayy", ":ayy2", ":ayy3", ":ayylmao", ":b8", ":baby", ":babyrage", ":babyyoda", ":backhead", ":backtowork", ":backup", ":bad", ":badidea", ":badopinionjuice", ":badpeach", ":badvibes", ":bag", ":baggie", ":bagworm", ":bagworm2", ":bah", ":baileys", ":bailout", ":bait", ":baited", ":baka", ":baldsquad", ":baller", ":ballin", ":balloons", ":balls", ":ballshit", ":ballshit2", ":ballshit3", ":bam", ":bam2", ":ban", ":ban2", ":ban3", ":banana", ":banana2", ":bananadance", ":band", ":bangin", ":banterman", ":barbGrump", ":barbgrump", ":bardmagic", ":bardmusicstops", ":barry", ":bashful", ":basic", ":basic2", ":basket", ":basketball", ":bass", ":batbro", ":batdontwant", ":batgrin", ":batman", ":bats", ":batsignal", ":bball", ":bbuddy", ":bbyoda", ":bchead", ":bcizfag", ":bcizfag2", ":bcizfag3", ":bcizzo", ":bcizzo2", ":bcizzzo", ":bde", ":beaman", ":bean", ":beanhair", ":beanlies", ":beans", ":beans2", ":beanshorts", ":bear", ":bearhype", ":beautiful", ":becky", ":becool", ":bedtime", ":beerus", ":bees", ":bees2", ":bees3", ":beesknees", ":beetdance", ":beetdance2", ":beetle", ":beezos", ":begwan", ":behappy", ":bellsprout", ":belt", ":bemyguest", ":benis", ":benis2", ":benmfw", ":benshiner", ":benvag", ":benvag2", ":bergfreund", ":bet", ":betterthanyou", ":bgdeer", ":bgdeer2", ":bgdown", ":bgglare", ":bgglare2", ":bggolddig", ":bgmfw", ":bgomg", ":bgomg2", ":bgpog", ":bgsadpost", ":bgsaladnaps", ":bgscooter", ":bgscooter2", ":bgshitpost", ":bgshitpost2", ":bgshitpost3", ":bgshitpost4", ":bgshitpost5", ":bgshitpost6", ":bgshitpost7", ":bgstfu", ":biden", ":biden2", ":bidenicecream", ":bidenmytime", ":bidet", ":bigawoo", ":bigbaby", ":bigbaby2", ":bigboi", ":bigboy", ":bigbrain", ":bigbrain2", ":bigbrain3", ":bigbrain4", ":bigbrain5", ":bigbrain6", ":bigbrain7", ":bigbrain8", ":bigbrain9", ":bigbro", ":bigface", ":biggerestyoshi", ":bighotdog", ":bigmood", ":bigperm", ":bigpog", ":bigretardjuice", ":bigsad", ":bigstardew", ":bigtitty", ":bigyell", ":bigyelltc", ":bigyoshi", ":bills", ":bird", ":birdman", ":birds", ":biscuit", ":bitch", ":bitchimight", ":bitchpls", ":bitcoin", ":bite", ":bitter", ":bjork", ":bjrok", ":blade", ":blade2", ":blahblah", ":blank", ":blargh", ":bleh", ":bleh2", ":blessed", ":blessed2", ":blessed3", ":blessyou", ":blindsinner", ":blink", ":blink2", ":blink3", ":blink4", ":blizzard", ":blobaww", ":blocked", ":blunt", ":blush3", ":blyat", ":bmo", ":bob", ":bob2", ":bobby", ":bobspin", ":bobteam", ":bog", ":bog2", ":bog3", ":bogdanoff", ":boi", ":boi2", ":boi3", ":boil", ":boiwave", ":bojack", ":bonecage", ":bonepolice", ":bones", ":boney", ":bongoblob", ":bongocat", ":bonk", ":bonk2", ":bonsai", ":boo", ":boobies", ":boobslap", ":booette", ":boofit", ":book", ":bookbreen", ":bookert", ":boom", ":boomer", ":boomer2", ":boomer3", ":boomeralert", ":boop", ":boosted", ":bootlegcody", ":bootlegcody2", ":bootlegcody3", ":booty", ":booty2", ":bootyhole", ":bootyshake", ":bootywave", ":bop", ":borat", ":bork", ":bork2", ":bossbitch", ":bounce", ":bow1", ":bow2", ":bowie", ":bowling", ":bowsette", ":boxxy", ":brackeys", ":brain", ":brainlet", ":brainlet2", ":brainlet3", ":brainlet4", ":brainlet5", ":brainlet6", ":brainlet7", ":brainlets", ":bratz", ":bravo", ":brazzers2", ":bread", ":break", ":breakfastcamel", ":breathe", ":brendan", ":brink", ":britcringe", ":britfalse", ":britoh", ":britshock", ":britthumb", ":britthumb2", ":britthumb3", ":britturn", ":brituh", ":britwut", ":britwut2", ":brityay", ":britzoom", ":broadcast", ":brogle", ":brokenmarbles", ":brokenrecord", ":bronco", ":brownie", ":brownie2g", ":brr", ":brrr", ":bruh", ":bsd", ":bsd2", ":bsdcat", ":bsdfap", ":bsdgivesup", ":bsdglare", ":bsdglare2", ":bsdhat", ":bsdnap", ":bsdrule", ":bsdshot", ":bsdtime", ":bubble", ":bubbles", ":buddy", ":bueller", ":bueno", ":buffalobill", ":buffcorrell", ":bug", ":bugyell", ":buhbye", ":bulk", ":bullshit", ":bullshit2", ":bullshit3", ":bulma", ":bunchadogs", ":bunnysmile", ":burd", ":burgers", ":burn", ":burning", ":burp", ":burst", ":bushes", ":bussy", ":bustea", ":bustin", ":bustin2", ":butt", ":butt2", ":butterdog", ":buttface", ":butthurt", ":butthurt2", ":butts", ":butwhysenpai", ":bwtf", ":bye", ":bye2", ":cab", ":cabbagepatch", ":cackle", ":cackle2", ":cackle3", ":cafe", ":cafe2", ":cafeoo", ":cafepog", ":calmdown", ":canada", ":canada2", ":cancelled", ":cancer", ":candlejack", ":cando", ":cantbeatthis", ":cantbeatthis2", ":cantwait", ":canudont", ":canunot", ":canwesmoke1st", ":canwesmokeweedinhere?", ":captain", ":cardicringe", ":cardigroce", ":cardigroove", ":carlton", ":carson", ":cashmoney", ":cat", ":cat2", ":catJAM", ":catdance", ":catface", ":catface2", ":catgrin", ":catjam2", ":catnik", ":catno", ":catperson", ":catsocks", ":catsteaks", ":catty", ":catugh", ":catyes", ":caughtit", ":cbreezy", ":cbreezy2", ":cbs", ":celery", ":celery2", ":celery3", ":celery4", ":celery44", ":celery5", ":celerygoipede", ":celerymad", ":celerysh", ":celerytrump", ":centrist", ":cereal", ":cermet", ":cerseimfw", ":cerseimfw2", ":certified", ":cg", ":chad", ":chadeyes", ":chadyes", ":chainsaw", ":chairs", ":chanceooo", ":chancla", ":chancla2", ":chancla3", ":chancla4", ":channingdance", ":chaz", ":checkem", ":checkthis", ":cheer", ":cheers", ":cheers2", ":cheers3", ":cheers4", ":cheerup", ":cheese", ":cheesenug", ":chefexcellence", ":chefkiss", ":chefkiss2", ":chidi", ":child", ":chili", ":chilidogs", ":chilimac", ":chill", ":chinchilla", ":chips", ":chocked", ":chockymilk", ":choke", ":christiswatching", ":chudspud", ":chudyes", ":chug", ":chungus", ":chungus2", ":ciggafry", ":cinderp", ":circle", ":cizzo", ":cizzorawr", ":clamps", ":clap", ":clap2", ":clap3", ":clap4", ":clap5", ":clap6", ":classic", ":claw", ":clench", ":clink", ":clippy", ":clockwork", ":closedforbusiness", ":clown", ":clown2", ":clowned", ":cmere", ":cmon", ":cmon2", ":cobra", ":cobraanime", ":cobradance", ":cobradance3", ":cobradance4", ":cobradefeat", ":cobraflip", ":cobrasnipe", ":cobrasnipe2", ":cobrasplit", ":cockit", ":cockslap", ":cocktail", ":codydoom", ":coffee", ":coffee4", ":coffeebreen", ":coffin", ":coffin2", ":coggers", ":coggers2", ":cold", ":cold2", ":coldcizzo", ":coldcizzo2", ":coldcizzo3", ":coldcizzo4", ":coldcizzo5", ":color", ":comeagain", ":communist", ":computer", ":computer2", ":concent", ":concern", ":coneheads", ":confusion", ":congrats", ":congratulations", ":conneck4", ":conor", ":conorcheese", ":conspiracy", ":context", ":contraband", ":cook", ":cook2", ":cooking2", ":cool", ":cooldawg", ":coolstory", ":cooper", ":cooper2", ":copham", ":cops", ":cops2", ":cops3", ":cops4", ":cops5", ":corndogbrother", ":corndogs", ":corona", ":corona2", ":coronatrump", ":cory", ":cough", ":country", ":country2", ":country3", ":covid-19", ":cowboy", ":crabdance", ":crabs", ":crackdance", ":crackdance2", ":crackle", ":crankykiru", ":crankykong", ":craptheboozeout", ":crash", ":crayons", ":crazy", ":creep", ":creepbrows", ":cricket", ":criesinkorean", ":criesinspanish", ":cringe", ":cringe2", ":cringe3", ":croc", ":crocs", ":cronch", ":cry", ":cry2", ":cry3", ":cryglasses", ":crying", ":crying2", ":crymask", ":crymask2", ":crypto", ":csense", ":cthulhu", ":cuck", ":cuddle", ":cuddle2", ":cuddle3", ":culmination", ":cumtown", ":cunt", ":cuntass", ":cup", ":currency", ":cute", ":cutieboots", ":cutiepatrick", ":cuties", ":cutyou", ":cyberbully", ":cyberbully2", ":cybermen", ":dab", ":dab2", ":dab3", ":dab4", ":dabbadont", ":dabes", ":dabonthehaters", ":dabs", ":dabs2", ":dabs3", ":dabs4", ":dabs5", ":dabs6", ":dadownsaesthetic", ":dadownz2", ":dadownzg", ":dafucklol", ":dafuk", ":dafuq", ":dagg", ":dahell", ":dahell2", ":damaged", ":damn", ":damn2", ":damn3", ":dance", ":dance10", ":dance11", ":dance111", ":dance113", ":dance12", ":dance13", ":dance14", ":dance15", ":dance16", ":dance17", ":dance18", ":dance19", ":dance2", ":dance20", ":dance21", ":dance22", ":dance23", ":dance24", ":dance25", ":dance26", ":dance27", ":dance28", ":dance29", ":dance30", ":dance4", ":dance5", ":dance6", ":dance7", ":dance8", ":dance9", ":dancingaway", ":dancingjesus", ":dandelion", ":danger", ":danymfw", ":darkness", ":datadeath", ":datashrug", ":datass", ":datatoke", ":datboi", ":daterape", ":daterape2", ":dbag", ":dea", ":dea2", ":dead", ":deadinside", ":deadinside2", ":deadinside3", ":deadinside4", ":dealwithit", ":deargod", ":death", ":deathdrop", ":deathpepe", ":debbiedance", ":decafe", ":deceased", ":decided", ":dedede", ":dee", ":deepfakefoul", ":deepfakerobo", ":deepfriedyuck", ":deepthought", ":deersuplex", ":delet", ":delet2", ":delet3", ":deletethis", ":deletthis", ":deletthis2", ":deletthis3", ":deletthis4", ":deletthis5", ":democrat", ":dendiface", ":denied", ":depression", ":derp", ":derp2", ":derp3", ":derputin", ":descent", ":despacito2", ":devil", ":devil2", ":devildog", ":dgaf", ":diarhea", ":diarreah", ":diarrhea", ":dick", ":dickbutt", ":dickcopter", ":dickdick", ":dickface", ":dickgate", ":dickpic", ":diddy", ":didntread", ":dinglet", ":dink", ":dio", ":dioo", ":dirty", ":disappear", ":disappoint", ":disappointedegg", ":disappointment", ":disapproval", ":discodog", ":disgood", ":disgust", ":disgust2", ":disgust3", ":disgusting", ":disliked", ":disperse", ":displeased", ":distresseddabbing", ":disturbed", ":diva", ":dj", ":dmt", ":dobradance", ":dodged", ":doe", ":doesntevengohere", ":dog", ":dog2", ":dog3", ":dog4", ":dog420", ":dog5", ":dog6", ":dog7", ":dog8", ":dog9", ":dogJAM", ":dogchamp", ":doge", ":dogtor", ":dogvil", ":doink", ":doinkpass", ":doinkphin", ":doinks", ":doinks2", ":doinks3", ":doit", ":doit2", ":dojagroove", ":dojagroove2", ":dokidoki", ":dome", ":donkeykong", ":donny", ":donotwant", ":dont", ":dontcare", ":dontdothat", ":dontlaugh", ":dontlaugh3", ":dontlikethat", ":dontmindme", ":dontshot", ":doom", ":doomer", ":doot", ":doot2", ":doot3", ":doot4", ":dootcheer", ":dootdance", ":dootkid", ":dootmindme", ":dootmyself", ":dootnope", ":dope", ":dope2", ":dopeasshit", ":dorito", ":dothecreep", ":dotheneedful", ":doublespiderman", ":doublingmoney", ":doubt", ":doubt2", ":douchenbsp", ":dove", ":dragon", ":dragonmeme", ":drake", ":drake2", ":drake3", ":drakemaybe", ":drakeno", ":drakeyes", ":drama", ":dramatic", ":dread", ":drink", ":drinkmilk", ":drinksinspanish", ":driveaway", ":drone", ":droogie", ":drool", ":drool2", ":drool3", ":drug", ":drugs", ":drugs2", ":drunk", ":drunk2", ":drunk3", ":dubs", ":duck", ":dudes", ":dudewipes", ":duel", ":duel2", ":duel3", ":duh", ":duh2", ":duh3", ":dukesilver", ":dumb", ":dumb2", ":dumbass", ":dumbbitch", ":dumbcunt", ":dumpit", ":dumpsterfire", ":dunce", ":dunce2", ":dunk", ":duo", ":duoloop", ":duoloop2", ":dura", ":dustin", ":dweeb", ":dwi", ":dwi2", ":dxm", ":dyel", ":e40", ":eargasm", ":eargasm2", ":earl", ":easymoney", ":eat", ":eatdapuss", ":eatmyshorts", ":eclipse", ":edgy", ":edgybsd", ":eel", ":eeyaa", ":egg", ":egg2", ":eggdrop", ":eggpepe", ":eggs", ":eggs2", ":eggs3", ":eggs4", ":eggsit", ":ehh", ":elephant", ":elephantpepe", ":elgo", ":ellen", ":elltc", ":elltc2", ":elltc3", ":elmo", ":elmofire", ":elon", ":elonduck", ":elontokes", ":elontokes2", ":elontokes3", ":elvira", ":elviratits", ":emergencyhug", ":emote", ":emotions", ":emotions2", ":emptychat", ":energyfeed", ":england", ":enhance", ":enhance2", ":enhance3", ":eoka", ":epico", ":erase", ":erect", ":et", ":etdance", ":eurobeat", ":evabonk", ":evaderp", ":evakiss", ":everybodydootnow", ":everyboy", ":evilhank", ":evilhank2", ":evilkermit", ":evilol", ":evilsmirk", ":evilsmirk2", ":ew", ":ew2", ":excellent", ":excite", ":excited", ":excited2", ":exist", ":exit", ":exodia", ":expanddong", ":expanddong2", ":expert", ":explain2", ":explode", ":exquisitemorty", ":extra", ":eyeboner", ":eyebrows", ":eyebrows2", ":eyebrows3", ":eyeroll", ":eyeroll2", ":eyeroll3", ":eyeroll4", ":eyeroll5", ":eyeroll6", ":eyes", ":eyy", ":ez", ":ezclap", ":f", ":faceass", ":faced", ":faceghost", ":faceoff", ":facepalm", ":facepunch", ":faget", ":fail", ":fake", ":fakeshock", ":fallenrocks", ":false", ":fap", ":fap3", ":fart", ":farthuffer", ":fascinating", ":fascist", ":fastdongs", ":fat", ":fatbastard", ":fatty", ":fatty2", ":fatty3", ":fatty4", ":fatty5", ":fawkesy", ":fazolis", ":fazzzoli", ":fear", ":feelings", ":feelinit", ":feels", ":feels2", ":feelsbadman", ":feelsbadman2", ":feelsgoodman", ":feet", ":feetmeat", ":female", ":fengas", ":fengas2", ":festive", ":fetish", ":fetish2", ":fetish3", ":fewinches", ":ffok", ":ffs", ":fgm", ":fgm2", ":fgm3", ":fgt", ":fhtagn", ":fierikiss", ":fif", ":fifi", ":fig", ":fight", ":fine", ":finger", ":fingerbang", ":fingerbang2", ":fingerbang3", ":fingerblast", ":fingergun", ":fingerguns", ":fingerguns2", ":fingerguns3", ":fire", ":firedup", ":fishdick", ":fishdickass", ":fishlessass", ":fist", ":fistbump", ":fists", ":fistshake", ":five", ":fivebeers", ":fixed", ":fixedit", ":fixit", ":flabbergasted", ":flames", ":flamethrower", ":flanders", ":flapping", ":flargenstow", ":flash", ":flatearthdad", ":flavorboi", ":flavorshot", ":flex", ":flex2", ":flex3", ":flex4", ":flman", ":floobs", ":florida", ":florida2", ":floss", ":flower", ":flowerbear", ":flubber", ":flyluigi", ":fml", ":fonzie", ":food", ":fool4", ":forsure", ":fouledit", ":foulironman", ":frau", ":freakedit", ":fred", ":fredcomp", ":fredhigh", ":fredreally", ":freecandy", ":fretard", ":friendly", ":friends", ":friends2", ":fries", ":frockflock", ":frog", ":frog2", ":frogchamp", ":frogeye", ":frogs", ":frogweed", ":frogwheel2", ":fsjal", ":fsjalgif", ":fu", ":fu2", ":fu4", ":fu5", ":fubean", ":fuckboy", ":fuckedup", ":fuckit", ":fucklove", ":fuckno", ":fuckpants", ":fucky", ":fuckyou", ":fuckyou2", ":fuckyou3", ":fuckyou4", ":fuckyourfeelings", ":fukippy", ":fullretard", ":fumbrella", ":funeral", ":funfact", ":funk", ":funny", ":furlong", ":furlong2", ":furry", ":fursure", ":futitan", ":futurefeet", ":fwut", ":gaben", ":gaben2", ":gachiflex", ":gag", ":gag2", ":gag3", ":gaga", ":gagano", ":gaganoyes", ":gagayes", ":gagging", ":garawrsale", ":garbage_day", ":garbagepeople", ":garfield", ":garfield2", ":garfield3", ":gasp", ":gay", ":gay2", ":gayfear", ":gayfear2", ":gayfera", ":gayfight", ":gaylaughter", ":gays", ":gayscreaming", ":gaysilence", ":gecko", ":geeked", ":gekko", ":gen", ":gendo", ":geniouse", ":genitals", ":genji", ":gentlemen", ":germandance", ":gethigh", ":getout", ":getout2", ":getouttahere", ":getsomehelp", ":gettheboat", ":ggag", ":ggag2", ":ghost", ":ghost2", ":ghostbj", ":girlbye", ":girlbye2", ":girlbye3", ":girlfight", ":girllegs", ":git", ":gitgud", ":giveup", ":glare", ":glitch", ":glitter", ":gloryhole", ":glow", ":glow2", ":glow3", ":glowapple", ":glowgm2", ":glowkine", ":glowloaf", ":glowloafyell", ":glowtiki", ":gm", ":gm2", ":gmerobo", ":gnome", ":goat", ":goatsame", ":goatse", ":goatse2", ":goaway2", ":goddamn", ":goddamn2", ":godzilla", ":gohome", ":gohome2", ":goingforweed", ":goku", ":goku2", ":goldblum", ":golmli", ":gonnacry", ":goob", ":goob2", ":good", ":goodday", ":goodforher", ":goodidea", ":goodnight", ":goodpoint", ":goodshit", ":goodshit2", ":goodweed", ":goofy", ":goofy2", ":googleit", ":goon", ":gore", ":gorl", ":goteem", ":gotem", ":gotem2", ":goten", ":gotenvstrunks", ":gotobed", ":gotohell", ":gottahavemyvape", ":gouge", ":gougeblock", ":graph", ":grats", ":graveyard", ":gray", ":greatpoint", ":greenmage", ":griffyell", ":grimes", ":grimes2", ":grimes3", ":grimes4", ":grin", ":grin2", ":grind", ":groce", ":grody", ":grogu", ":groove", ":groovetown", ":gross2", ":grossno", ":grouphug", ":gubment", ":guesswhat", ":guillermo", ":gulag", ":gulp", ":gun", ":guntalk", ":gurl", ":guts", ":h3stare", ":h8", ":ha-ha", ":hab", ":hacker", ":hackerman", ":hacking", ":hacking2", ":hacking3", ":hacking4", ":hades", ":hagay", ":haha", ":hahano", ":hahawat", ":hahayes", ":hairflip", ":hairflip2", ":ham", ":hamkiss", ":hammond", ":hamtaro", ":hand", ":handgun", ":handled", ":handrub", ":handsome", ":handthing", ":handthing2", ":hangon", ":hank", ":hank2", ":hankgasm", ":hannibalburesshumpingkfc", ":hansen", ":hanukkah", ":hanukkah2", ":happy", ":happy2", ":happymask", ":happythonk", ":hard", ":hardpass", ":hashbash", ":hate", ":hate2", ":hathair", ":hating", ":hattip", ":hattip2", ":hattip3", ":hatwobble", ":hatwobble2", ":hb", ":hb2", ":hb3", ":hb4", ":hb5", ":hbd", ":hbdqueer", ":headbang", ":headbang2", ":headphones", ":headtoss", ":healer", ":heart", ":hearteyes", ":heather", ":heavybreathing", ":heckyeah", ":heh", ":heh2", ":hehe", ":heimlich", ":hellfrasier", ":hellno", ":hello", ":hello2", ":hellyeah", ":hellyeah2", ":helmetcizzo", ":helth", ":henry", ":heretical", ":herpes", ":herpes2", ":hewwo", ":hey", ":hgih", ":hh", ":hhh", ":hi", ":hi2", ":hi3", ":hibye", ":hicafe", ":hieverybody", ":high", ":high10", ":high11", ":high2", ":high3", ":high4", ":high6", ":high7", ":high8", ":high9", ":highaf", ":highfive", ":hilamfw", ":hillarydance", ":hips", ":hipstr", ":hiss", ":hiss2", ":hiss3", ":hitler", ":hitler420", ":hitormiss", ":hiya", ":hjk", ":hltrcold", ":hltrdance", ":hltrdance2", ":hltrhm", ":hltrlma", ":hltrmakeup", ":hltrscream", ":hltrshitpost2", ":hm", ":hmm", ":hmm2", ":hmm3", ":hmm4", ":hmm5", ":hng", ":hnng", ":hoatse", ":hockeyshow", ":holdingback", ":holdme", ":holdme2", ":holdon", ":holdup", ":holes", ":homer", ":homerout", ":homerrave", ":homervagina", ":hon", ":honestly", ":honk", ":honkhonk", ":honmer", ":horny", ":hornyjail", ":horoor", ":horror", ":hoss", ":hotboxed", ":hotdog", ":hotdogs", ":hotdogs2", ":hotdogs3", ":hotlick", ":houseguest", ":hoverloop", ":hovervape", ":howboutthat", ":howdareyou", ":howhigh", ":howrude", ":hthrass", ":https://vidble.com/ypIKFZFqtD.jpg", ":hue", ":huehue", ":huehuehue", ":huehuehuehue", ":huff", ":hug2", ":hug3", ":huh", ":huh2", ":hulk", ":hump", ":hungover", ":hungover2", ":hungry", ":hungry2", ":hurrthur", ":hyped", ":hyperpug", ":hypno", ":hypnotoad", ":icebar", ":icecream", ":icescream", ":icu", ":icy", ":idc", ":idcaa", ":idec", ":idek", ":idfk", ":idgad", ":idgaf", ":idgas", ":idk", ":idk2", ":idubbbz", ":ifeelit", ":ignore", ":igotyou", ":iguess", ":ihatethis", ":iknow", ":ilikeeggs", ":ilikeyou", ":illallowit", ":illwait", ":ilu", ":imdabes", ":imfine", ":imgay", ":imgay2", ":imgrown", ":imhelping", ":imin", ":imok", ":imokay", ":imokay2", ":imout2", ":imout3", ":imout4", ":imout5", ":imp", ":impossible", ":imtelling", ":ina", ":inanet", ":inapropriate", ":indeed", ":indupotato", ":ineedanadult", ":inhaler", ":internet", ":ipog", ":iquit", ":irl", ":iroll", ":ironman", ":isaid", ":isaidwhatisaid", ":isay", ":ishitdick", ":italianspiderman", ":itcouldhappen", ":its420", ":itshot", ":itsme", ":itsme2", ":itsover", ":itstinks", ":jacozi", ":jacuzzi", ":jake", ":james", ":jammies", ":jawdrop", ":jazzhands", ":jazzstops", ":jeff", ":jeff2", ":jeffthonk", ":jerk", ":jews", ":jg", ":jimmydean", ":jinx", ":jinx2", ":jizz", ":jizz2", ":jizz3", ":jk", ":joe", ":joeexotic", ":joint", ":joke", ":joker", ":jones", ":jordan", ":joshpog", ":joshpoguu", ":judge", ":judging", ":judy", ":juggalo", ":juice", ":juice2", ":juices", ":juicy", ":jumpingjacks", ":junkboy", ":jupiter", ":just", ":justice", ":justright", ":k2", ":kaceycough", ":kahuna", ":kakama", ":kalm", ":kamschin", ":kamsdance", ":kannasus", ":kanye", ":kanyeshrug", ":kanyesneer", ":kanyeyell", ":kappa", ":karatecat", ":karen", ":kate", ":katy", ":kawaii", ":kawaii2", ":kawaiipepe", ":keanuwhoa", ":keepgoing", ":kek", ":kek2", ":kek3", ":kek4", ":keks", ":kenan", ":ketafed", ":ketaset", ":ketru", ":kevin", ":kevinsmith", ":kf2", ":kfc", ":kick", ":kick2", ":kickedin", ":kidpronto", ":kids", ":kidzbop", ":kill", ":kill2", ":kill3", ":killanazi", ":killmyself", ":killthem", ":king", ":kippy", ":kippychip", ":kippyfu", ":kirby", ":kirbygroove", ":kirbygun", ":kiss", ":kissahomie", ":kitty", ":kkmad", ":kkomg", ":kkstare", ":kms", ":kms2", ":kms3", ":kms4", ":kms5", ":kms6", ":kms7", ":kms8", ":kmswojak", ":kneadin", ":knife", ":knifedick2", ":knifedickass", ":knifedickg", ":knifefight", ":knockoffrawr", ":kojima", ":kojima2", ":kombushot", ":kombuwut", ":kong", ":korndawg", ":koth", ":krabbyg", ":krabbypatties", ":krabs", ":krabs2", ":kreayshawndance", ":kysmcdermit", ":laff", ":laforgeno", ":laforgeyes", ":lain", ":lapras", ":larp", ":larrity", ":larry", ":larry2", ":larry3", ":laughing", ":laughingboys", ":laughingelfman", ":laughinggirls", ":laughinggirls2", ":laughingprincesses", ":laughingscps", ":laughingscrolls", ":laughingwatch", ":laura", ":leaf", ":learnding", ":leatherface", ":leavemehere", ":leavethemalone", ":leedle", ":leg", ":legs", ":lel", ":lemon", ":lemonparty", ":lemonparty2", ":lemons", ":lenny", ":lenny2", ":lenny3", ":lennythumbsup", ":lesfest", ":letmein", ":letmein2", ":letsfuck", ":letsget", ":levi", ":lewdnood", ":lick", ":lick2", ":lick3", ":lies", ":lightsout", ":like", ":lil", ":lilb", ":lilbg", ":lilrawr", ":lilrawr2", ":lilrawr3", ":lime", ":link", ":linusfinger", ":lion", ":lisa", ":lisaroll", ":lisasis", ":list", ":lit", ":lit2", ":lit3", ":lit4", ":lit5", ":lit6", ":liteparty", ":literally", ":lizzieroll", ":lizzo", ":lma", ":lmao", ":lmaok", ":lmfao", ":loafshot", ":loafyell", ":logan", ":logic", ":logoff", ":lol", ":lol2", ":lol3", ":lol4", ":lol5", ":lolfu", ":lolfuckyou", ":lolfuckyoutoo", ":longbullshit", ":longhead", ":longlung", ":longshit", ":longstory", ":lookatme", ":looking", ":loom", ":loser", ":loud", ":loudjazz", ":love", ":lovecraft", ":loveit", ":loveme", ":lovethat", ":lsd", ":lsdbreakfast", ":lt", ":luigi", ":luigi2", ":luigidance", ":luigimario", ":lurk", ":lurker", ":lurker2", ":lyin", ":lying", ":m4ndablow", ":ma", ":mad", ":mad2", ":mad3", ":mad4", ":mad5", ":mad6", ":madatu", ":madham", ":madham2", ":madluigi", ":madoka", ":madspongebob", ":maga", ":maggiedance", ":magic", ":magic_spit_bubble", ":magical", ":magina", ":magnifico", ":makeitrain", ":makeittrain", ":malibu", ":mandela", ":mandfinger", ":mangina", ":mango", ":mansplaining", ":marge", ":marginal", ":mari", ":mario", ":mariodrugs", ":marx", ":masenko", ":maskoff", ":maskon2", ":math", ":math2", ":math3", ":matrixbg", ":matrixwtf", ":matsu", ":may", ":maybeso", ":mayday", ":mcafeefinger", ":mcchicken", ":mccree", ":mcdermit", ":mcdermit2", ":mcree", ":me_irl", ":mean", ":meangirl", ":meangirls", ":meatfeet", ":meatspin", ":meatspin2", ":meaty", ":megadab", ":meivape", ":melt", ":meltman", ":memeforants", ":mememyshitup", ":memes", ":mentalillness", ":meow", ":mercykilling", ":mercymfw", ":merry", ":metal", ":meth", ":methladin", ":mewtwo", ":mhm", ":mhm2", ":mhm3", ":mhm4", ":microphone", ":migi", ":mikekowalski", ":miko", ":miko2", ":miko3", ":miko4", ":mikohello", ":mikohello2", ":milly", ":mind", ":mindblown", ":mindblown2", ":mindmeld", ":mine", ":mineblown", ":mini", ":mini2", ":miniout", ":misato", ":misato2", ":misato3", ":misatodrank", ":missu", ":mistake", ":mistermime", ":mj", ":mj2", ":mj3", ":mj4", ":mj5", ":mjbump", ":mjdance", ":mjeye", ":mjfive", ":mjpv", ":mjweedwacker", ":mlem", ":mm2", ":mm3", ":moar", ":mock", ":mock2", ":mockingsponebob", ":mockingspongebob", ":modabuse", ":moe", ":moist", ":moistpog", ":molly", ":mommylongarm", ":momo", ":momo2", ":monarch", ":monarch2", ":money", ":monkas", ":monkas2", ":monkass", ":monkeyproject", ":monks", ":monogamy", ":moo", ":mood", ":moonman", ":moose", ":morecoffee", ":morning", ":morninghlts", ":mortar", ":motherfucker", ":mothermary", ":motorboat", ":mouthbar", ":move", ":mrcoolice", ":mrcoolice2", ":mrmanhattan", ":mspepe", ":mtj", ":munchies", ":munchies2", ":murph", ":murphy", ":mushroom", ":mxe", ":mycorona", ":myjam", ":mystery", ":n8mjpede", ":naggawife", ":nah", ":nah2", ":nah3", ":nahduster", ":nahfkthis", ":naked", ":nancy", ":nanner", ":naruto", ":narutosquint", ":nasty", ":nbsp", ":nbsp2", ":nbspdicks", ":neckbeard", ":neek", ":neek2", ":neek3", ":neekglow", ":neekolai", ":neezy", ":neo", ":neon", ":neptube", ":neptune", ":nerd", ":nerd2", ":nerd3", ":nerdalert", ":nerdalert2", ":nerds", ":nervous", ":nervousgay", ":netidwi", ":newtonwhodis", ":next", ":nice", ":nice2", ":nice9000", ":niceopinion", ":nickdance", ":nigel", ":nigel2", ":night", ":nini", ":ninja", ":niptuck", ":nkhighfive", ":no2", ":no3", ":no4", ":no5", ":nobeans", ":nobed", ":nobodycares", ":nocapes", ":nochancla", ":nod", ":nod2", ":nod4", ":nodawg", ":noeggs", ":nofun", ":nohomo", ":nohomo2", ":noice", ":noidea", ":nom", ":nom2", ":nomalone", ":nonames", ":noneed", ":nono", ":nono2", ":nonono", ":noodle", ":noone", ":noonecares", ":nope", ":nope2", ":nope3", ":nope4", ":nope5", ":noragrets", ":norobo", ":nosedab", ":nosense2", ":notahomo", ":note", ":noteeth", ":noteeth2", ":noteeth3", ":notes", ":notexcite", ":nothanks", ":nothankyou", ":nothingmatters", ":noticemekohai", ":notimportant", ":notkawaii", ":notlit", ":notnice", ":notnice2", ":notshitfaced", ":notthisshitagain", ":nottoday", ":noty", ":nou", ":now2", ":nowae", ":nowell", ":nowkith", ":noyee", ":noyell", ":nsnap", ":numa", ":nurple", ":nut", ":nutella", ":nutmilk", ":nyarlothotep", ":nyess", ":o", ":o_O", ":oatmeal", ":obamagun", ":obana", ":obie", ":obie2", ":obie3", ":obie4", ":objection", ":obonga", ":og", ":oh3", ":oh?", ":ohboy", ":ohgod", ":ohh", ":ohhimark", ":ohi", ":ohjam", ":ohjam2", ":ohmyfuck", ":ohmygod", ":ohno", ":ohno2", ":ohnobaby", ":ohok", ":ohshit", ":ohsnap", ":ohsnap2", ":ohstop", ":ohya?", ":ohyeah", ":ohyou", ":ok", ":ok2", ":okay", ":okay2", ":okaydotpng", ":okboomer", ":okhon", ":okkid", ":old", ":oldbsd", ":oldfag", ":oldgregg", ":oldmeme", ":oldschoolcool", ":oli2", ":olipepe", ":omegadance", ":omg", ":omg2", ":omg3", ":omgg", ":omgno", ":omgwtf", ":omgwtfbbq", ":omyac", ":oneofus", ":onesec", ":oo", ":oof", ":oof2", ":ooo", ":oooo", ":ooooo", ":oooooo", ":opinion", ":oprah", ":oralsex", ":orly", ":oshit", ":otter", ":otter2", ":otter3", ":otterdance", ":ottermad", ":ouch", ":ours", ":out", ":out2", ":owlhaha", ":packel", ":packel2", ":packelshot", ":packelsmirk", ":packing", ":paid", ":painedmoans", ":paint", ":paint2", ":palmhead", ":panda", ":panduichooseu", ":panic", ":panik", ":pantymask", ":pantymask2", ":parched", ":parrot", ":party", ":party2", ":partyhard", ":partypug", ":pashmina", ":pat", ":pathetic", ":pathetic2", ":pathetic3", ":pattrick", ":paulblart", ":paulyd", ":pb", ":pbr", ":pc", ":pcrage", ":pd", ":pea", ":peace", ":peace2", ":peaceout", ":peaceout2", ":pecs", ":peeinthebutt", ":peek", ":peek2", ":peekcat", ":peekin", ":peep", ":peepoclap", ":peepogoose", ":peepohappy", ":peeporun", ":peeposad", ":peggytriggered", ":penpen", ":pepe", ":pepe2", ":pepeblanket", ":pepeblush", ":pepeboi", ":pepeboom", ":pepecheers", ":pepeclap", ":pepeconcern", ":pepecop", ":pepedance", ":pepedoll", ":pepedonut", ":pepeenhance", ":pepefeels", ":pepega", ":pepegacard", ":pepegadrive", ":pepegasteer", ":pepegrin", ":pepegun", ":pepegun2", ":pepehappy", ":pepehappy2", ":pepejam", ":pepejerk", ":pepekek", ":pepelurk", ":pepelurk2", ":pepemoney", ":pepenaruto", ":pepenugget", ":pepepepe", ":pepepig", ":pepepizza", ":pepepog", ":peperetarded", ":peperona", ":peperun", ":pepesad", ":pepesad2", ":pepesilvia", ":pepesimp", ":pepesleeps", ":pepesmoke", ":pepesmoke2", ":pepespin", ":pepestar", ":pepestfu", ":pepesweat", ":pepeuwu", ":pepevape", ":pepewhy", ":pepework", ":perfect", ":perfectsense", ":perma", ":perry", ":personalspace", ":personnel", ":pet", ":peterson", ":phew", ":philly", ":pho", ":phone2", ":phonedoot", ":phrasing", ":phrasing2", ":picklebob", ":picklerickg", ":pigpen", ":pikahegao", ":pills", ":pimple", ":pimple2", ":pinch", ":ping", ":ping2", ":pinged", ":pissedoff", ":piypiy", ":pizza2", ":pizzacat", ":pizzachan", ":pizzamail", ":pizzaparty", ":planet", ":plankton", ":plant", ":platmad", ":pleased", ":pleasehold", ":pleaseno", ":pls", ":pls2", ":pls3", ":pocketsand", ":podiumguy", ":pog", ":pogged", ":poggers", ":poggie", ":pogtasty", ":pogu", ":poguu", ":point", ":point2", ":point3", ":pokibass", ":police", ":poo", ":poobrain", ":poolmonster", ":pop10", ":popcorn", ":popcorn2", ":popcorn3", ":popo", ":poppyd", ":poppyhi", ":pops", ":popwindow", ":porkpork", ":pose", ":posture", ":potatocam", ":pounce", ":pounce2", ":pp", ":prankd", ":preach", ":pretend", ":prettypepe", ":prisma", ":problems", ":prof", ":profbunny", ":profdance", ":protagonist", ":protip", ":protoncannon", ":protoncannon2", ":psyduck", ":psyswoon", ":pugpls", ":puke", ":puke2", ":puke3", ":pullup", ":pun", ":punch", ":punch3", ":punkrock", ":puppetpals", ":puppeyface", ":pure", ":push", ":pusse", ":pussy", ":putan", ":putin", ":putlitterinitsplace", ":pv", ":pwease", ":pyro", ":pyro2", ":qq", ":quinceanera", ":raccoon", ":racist", ":rad", ":radio", ":rage", ":rage2", ":rage3", ":rain", ":ralph", ":rambo", ":ramen", ":ramiel", ":ramiel2", ":ranch", ":range", ":rant", ":rastaluigi", ":rastamario", ":ratJAM", ":ratchet", ":ratman", ":rattle", ":rave", ":ravedolf", ":raven", ":ravioli", ":raw", ":rawr", ":rawrbo", ":rawrbo2", ":rawrbutt2", ":rawrbutt3", ":rawrbutt4", ":rawrfuneral", ":rawrglow", ":rawrgrayons", ":rawrgun", ":rawrkeys", ":rawrkeys2", ":rawrliebrown", ":rawrloom", ":rawrmelt", ":rawrmix", ":rawrning", ":rawrpepe", ":rawrself", ":rawrshere", ":rawrshred", ":rawrstinks", ":rawrtc", ":rawrtits", ":rbf", ":reacharound", ":ready", ":real", ":realistdoot", ":really", ":really12", ":really2", ":reallydude", ":reallytired", ":redcard", ":redzz", ":redzz2", ":redzz3", ":ree", ":reecat", ":reference", ":rei", ":reign", ":rekt", ":rektpepe", ":relax", ":replicantgaze", ":reported", ":reportme", ":repulsed", ":rero", ":respek", ":retarded", ":reversedatass", ":reverseputin", ":rgr", ":ribba", ":ricardo", ":ricardo2", ":ricardo3", ":ricardo4", ":ricardosmile", ":ricardosmile2", ":richard", ":richpeople", ":rick", ":rickross", ":riddle", ":right", ":riotsinphili", ":rip", ":ripclouds", ":ripit", ":rips", ":rips3", ":ripsyeah", ":rita", ":robert", ":robin", ":robo", ":roboJAM", ":robocop", ":roboelon", ":robojam", ":robojoker", ":robokevin", ":robokrabs", ":robomcdonald", ":robomeat", ":robonewyears", ":roboof", ":robopaint", ":robopodiumguy", ":roboshrek", ":roboslime", ":robostonks", ":robotnik", ":roboxmas", ":roboxmas2", ":roboxmas3", ":roboxmas4", ":rock", ":rocking", ":rockydennis", ":rogan", ":rogecam", ":rogepeace", ":roger", ":roger2", ":roger3", ":rogerbye", ":rogerdance", ":rogersanchez", ":rogerthat", ":rollin", ":rolling", ":rollsafe", ":rolltide", ":rose", ":ross", ":rotom", ":rtj", ":rtj2", ":rtj3", ":rub", ":rudd", ":rude", ":rudymelt", ":rum", ":runhand", ":runhands", ":rup", ":rush", ":rustupid", ":rybrows", ":ryu", ":sachiel", ":sad", ":saddawg", ":sadge", ":sadgestrain", ":sadhaha", ":sadham", ":sadman", ":sadpanda", ":sadrunk", ":sadscream", ":safetydance", ":sailorette", ":salad", ":salsaverde", ":salsaverde2", ":salsaverde3", ":salty", ":salty2", ":sancho", ":sandwich", ":sanic", ":sanic2", ":santashot", ":sarcasm", ":sarcastic", ":sass", ":sass2", ":sasstoke", ":sassy", ":sasukefsjal", ":satan", ":satanlingus", ":savage", ":saywhat", ":scarlett", ":scarypopcorn", ":scoot", ":scooter", ":scooter2", ":scram", ":scream", ":scream?", ":screech", ":scurd", ":seduce", ":seduce2", ":seent", ":seeyou", ":selena", ":selfcrit", ":senorsassy", ":serg", ":serg2", ":serg3", ":sergdown", ":sergflex", ":severalboys", ":severaldayslater", ":sex", ":sexsign", ":sexybunny", ":sexybunnyathome", ":sexylamo", ":shade", ":shadow", ":shaggy", ":shaggymock", ":shake", ":shambooty", ":shame", ":shameless", ":shamhigh", ":shania", ":shania2", ":shania3", ":shania4", ":shaq", ":shaq2", ":shaqpanda", ":shaqsleep", ":shaw", ":shieeet", ":shifty", ":shinjiangst", ":shinjibate", ":shinsuka", ":shit", ":shitass", ":shitpost", ":shitposting", ":shitsweak", ":shocked", ":shocked2", ":shocked4", ":shocked5", ":shocked6", ":shocked7", ":shockedx", ":shoo", ":shoo2", ":shook", ":shopped", ":shortcat", ":shortcat2", ":shots", ":shots2", ":shots3", ":shots4", ":shots5", ":shower", ":showtime", ":shrek", ":shrimppog", ":shrimpwave", ":shroom", ":shroomin", ":shrug", ":shrug2", ":shrug3", ":shutup", ":shutup2", ":shutyourup", ":shy", ":shy2", ":shy3", ":shy4", ":sideeye", ":sigh", ":sike", ":sike2", ":silence", ":silence2", ":silencesimp", ":silentagree", ":sillybrit", ":simone", ":simp", ":simped", ":simpstampede", ":sims", ":singlet", ":sip", ":sip2", ":sipcup", ":sips", ":sips2", ":sipstea", ":sis", ":sisterrawr", ":sit", ":skeledance", ":skeletons", ":skeletor", ":skeptical", ":skills", ":skipit", ":skrrt", ":skrt", ":skrtskrt", ":skull", ":skull2", ":slampoetry", ":slap", ":slap2", ":slap3", ":slapbass", ":sleep", ":sleepduck", ":sleepytime", ":slime2", ":slimer", ":slinky", ":slooptime", ":slowjam", ":slowpoke", ":slowsmile", ":slurp", ":slurp2", ":slurp3", ":slut", ":sluttery", ":smack", ":smackdown", ":smackdown2", ":smallbrain", ":smallbrain2", ":smallpenis", ":smallyell", ":smart", ":smart2", ":smart3", ":smartcell", ":smarthouse", ":smbh", ":smd", ":smd2", ":smell", ":smell2", ":smellgood", ":smh", ":smh2", ":smh3", ":smh4", ":smh400", ":smile2", ":smile3", ":smile4", ":smile5", ":smile6", ":smile7", ":smile8", ":smiley", ":smirk", ":smirk2", ":smithers", ":smoke", ":smoke2", ":smoke3", ":smoke4", ":smoke5", ":smoke6", ":smokebomb", ":smooth", ":smoothie", ":smort2", ":smug", ":smug2g", ":smug3g", ":smug4g", ":smug5", ":smug6", ":smugasuka", ":smuggered", ":smugharuhi", ":smuginvulcan", ":smugmask", ":smugspongebob", ":snackbraff", ":snacks", ":snake", ":snap", ":sneer", ":snoop", ":socute", ":sodivie", ":sodivin", ":sodivine", ":softdoot", ":sofunny", ":sofunny2", ":sogood", ":sohigh", ":sohigh2", ":sohigh3", ":sohigh4", ":sohigh5", ":soiledit", ":solit", ":sonicdab", ":sooie", ":soon", ":sorry", ":sorude", ":sot", ":soupfrog", ":souptime", ":sour", ":soylentgreen", ":space", ":spacepalm", ":spaghettio", ":spam", ":spank2", ":sparkit", ":spate", ":spear", ":spicy", ":spider", ":spider2", ":spider3", ":spiderman", ":spiderpants", ":spiderspank", ":spiderspank2", ":spin", ":spin2", ":spit", ":spit2", ":spitcatch", ":spitroast", ":spoiler", ":spoken", ":spongegar", ":spongehigh", ":spook", ":spooky", ":spoon", ":spray", ":spuddy", ":squad", ":square", ":squart", ":squidwardshouse", ":squint", ":squint2", ":squint3", ":squint4", ":squint5", ":squint6", ":squirt", ":squirtle", ":squirtlelaugh", ":srsbsns", ":srsly", ":sryboutit", ":ssh", ":stab", ":stab2", ":stahp", ":stairs", ":star", ":star2", ":stare", ":stare2g", ":stare3", ":stare4", ":stare5", ":stare6", ":stare7", ":stare8", ":staremotherfucker", ":staresinarkansan", ":staresingoth", ":staresinholy", ":staresinillinois", ":staresinklingon", ":staresinscience", ":staresinsmartass", ":staresintexan", ":steak", ":steamed", ":steyerdance", ":stfu", ":stfu2", ":stfu3", ":stig", ":stillhorny", ":stink", ":stinkeye", ":stinks", ":stoked", ":stolen", ":stolen2", ":stoned", ":stoneduster", ":stonks", ":stont", ":stont2", ":stop", ":stop2", ":straight", ":straightluigi", ":strain", ":strain2", ":strangestthing", ":stress2", ":strongjazz", ":strut", ":strut2", ":stupid", ":stupid2", ":stupid3", ":suckit", ":suckmyass", ":sucks", ":sucks2", ":suh", ":suh2", ":suh3", ":suh4", ":suh5", ":suh6", ":suh7", ":suh8", ":suibag", ":suicide", ":sum41", ":sunlamp", ":sup", ":sup2", ":superkick", ":sure", ":sure2", ":surejan", ":surprised", ":sus", ":sushi", ":swag", ":swag2", ":swag3", ":swamp", ":swampjustice", ":sweating", ":sweaty", ":sweaty2", ":sweeplegcobra", ":sweetberrywine", ":sweg", ":swerve", ":swine", ":swoon2", ":swoon3", ":swoon4", ":swoon5", ":tablebye", ":taco", ":tacotown", ":tacticaldab", ":takedown", ":takemelord", ":talkingwords", ":tang", ":tapbrothers", ":tarnation", ":tarnation2", ":tarnation3", ":tarot", ":tasty", ":tasty2", ":taylorshrug", ":tea", ":teabag", ":tears", ":technicallycorrect", ":technoviking", ":teehee", ":tehepelo", ":telos", ":telosreported", ":tendie", ":terror", ":terry", ":texas", ":tf", ":tf3", ":tfdude", ":tfisthis", ":thankyou", ":thatgayshit", ":thatsgaydoot", ":thatsthejoke", ":thc", ":theboys", ":theboys2", ":thedude", ":thejoke", ":thermalfart", ":thewhat", ":theworst", ":thi", ":thirdeye", ":thirst", ":thirsty", ":this", ":thisasshole", ":thischat", ":thisguy", ":thisguy2", ":thisme", ":thiswhomps", ":thisyear", ":thonghole", ":thonk", ":thot", ":thousandsoftears", ":threwup", ":throckmorton", ":thrust", ":thrust2", ":thumbs", ":thumbsup", ":thumbsup2", ":thumpsup", ":thumpsup2", ":thwonk", ":tiedyedforyoursins", ":tight", ":tiki", ":tiki2", ":tikifly", ":tikifu", ":tikihead", ":tikikat", ":timefordat", ":timfoil", ":tinfoil", ":tinfoil2", ":tinyface", ":tinytext", ":tinytinytext", ":tip", ":tiredspongebob", ":tits", ":tldr", ":tldr2", ":tlol", ":tmyk", ":toad", ":token", ":tom", ":tomate", ":tone", ":tongue", ":tongueeyes", ":tongueeyes2", ":tongueme", ":tongueme2", ":toofastboi", ":toohigh", ":toolate", ":tori", ":torso", ":totino", ":tots", ":touche", ":towelhead", ":toystory", ":tradition", ":tranquility", ":transference", ":trap", ":trap2", ":trash", ":trashduster", ":travolta", ":treat", ":tried", ":tried2", ":triggered2", ":trihard", ":tripepe", ":tripog", ":trisha", ":troll", ":troubleshooting", ":truckdab", ":trump", ":trump2020", ":trumpdance", ":truth", ":trying", ":ttj", ":ttom", ":tubbob", ":tubgirl", ":tuesday", ":tumblr", ":tumblr2", ":tunabreen", ":turkey", ":turnip", ":turnips", ":turnup2", ":turtle", ":twat", ":twerk", ":twerk2", ":twerky", ":twerky2", ":twomad", ":typing", ":typing2", ":tyring", ":tysir", ":ubergarf", ":udderlyridiculous", ":ugh", ":ugh2", ":ugly", ":uglycry", ":uh", ":uhhh", ":uhoh", ":uhungry", ":uicide", ":ukine", ":ukine2", ":ulul", ":um", ":umad", ":unacceptable", ":unamused", ":uncomfortablepepe", ":undertaker", ":unicornbhole", ":uniel", ":uninhance", ":unless", ":unlimited", ":uno", ":unoit", ":unree", ":urbutt", ":urdumb", ":urnotspecial", ":usa", ":usure", ":utena", ":uwanfite", ":uwot", ":uwusato", ":uzi", ":uzi2", ":vagina", ":valium", ":valorant", ":vampire", ":vampire2", ":vapenaysh", ":vaping", ":vaporblush", ":vegeta", ":vegeta2", ":verysad", ":vibes", ":villager", ":violin", ":violin2", ":vitalik", ":vitalik2", ":vivec", ":vivec2", ":vodka", ":vogue", ":volk", ":vomit", ":vomit2", ":waah", ":wack", ":wack2", ":wackyjesus", ":waddle", ":wafu", ":wah", ":wahs", ":waiting", ":waiting2", ":wakaok", ":waluass", ":waluigi", ":waluigi2", ":waluigi3", ":waluigi4", ":waluigi5", ":waluweiner", ":wannaplayow", ":want", ":warcraftincel", ":wario", ":warp", ":washer", ":washsomething", ":wasted", ":wat", ":wat2", ":wat3", ":wat4", ":wat5", ":watchinyou", ":watchinyou2", ":watdawg", ":water", ":waterfalls", ":waterfart", ":wave", ":wave2", ":wave3", ":wave4", ":waveboi", ":wazzup", ":wditmf", ":weather01d", ":weather01n", ":weather02d", ":weather02n", ":weather03d", ":weather03n", ":weather04d", ":weather04n", ":weather09d", ":weather09n", ":weather10d", ":weather10n", ":weather11d", ":weather11n", ":weather13d", ":weather13n", ":weather50d", ":weather50n", ":weeaboo", ":weeb", ":weebalert", ":weebshit", ":weed", ":weedqueen", ":weepanddie", ":weewooweewoo", ":weh", ":weiner", ":weirdchamp", ":welcome", ":wellfuck", ":wellinever", ":welp", ":werecar", ":wgw", ":wgw2", ":wgw3", ":wgw4", ":wharffoil", ":what", ":what3", ":whatever", ":whatever2", ":whisper", ":whiteface", ":who", ":whoa", ":whoareyou", ":whocares", ":whocares2", ":whogivesafuck", ":whoosh", ":whoseline", ":whotold", ":why", ":why2", ":why3", ":whynot", ":widepeepo", ":widepeepohappy", ":wideputin", ":widerobo", ":widow", ":wiggle", ":wigglerette", ":winebitch", ":winebitch2", ":winevac", ":wink", ":wink2", ":wink3", ":wink4", ":wink5", ":wiseguy", ":witch", ":wiwicat", ":wizard", ":wk", ":wk2", ":woah", ":woaw", ":wojak", ":wojak2", ":woke", ":wokeaf", ":wolfofrobo", ":womb", ":women", ":wompwomp", ":wonkastop", ":woo", ":woody", ":woogity", ":wook", ":wookie", ":wootshot", ":words", ":work", ":work2", ":working", ":worksucks", ":worktime", ":worldstar", ":worried", ":worry", ":worry2", ":wow", ":wow2", ":wow3", ":wow4", ":wow5", ":woww", ":wrong", ":wrongkiddo", ":wtf", ":wtf2", ":wtf3", ":wtf4", ":wtf5", ":wuh", ":wuhell", ":wukakke", ":wunips", ":wusass", ":wut", ":wut2", ":ww3", ":xanax", ":xanax2", ":xanax3", ":xd", ":xena", ":xmas", ":xqcblush", ":xtracheese", ":yachty", ":yachtydance", ":yachtyshh", ":yachtywink", ":yada", ":yallmad", ":yanasty", ":yandere", ":yandereahegao", ":yanderewave", ":yang", ":yass", ":yass2", ":yass3", ":yawn", ":yay2", ":yay3", ":yay4", ":yay5", ":yeah", ":yeahweknow", ":yee", ":yee2", ":yeee", ":yeenaw", ":yeeted", ":yeeyee", ":yeezugh", ":yell", ":yell2", ":yep", ":yes", ":yes2", ":yes3", ":yes4", ":yes5", ":yes6", ":yes7", ":yesyesno", ":yike", ":yike2", ":yikes", ":yikes2", ":yikes3", ":yikes4", ":yipyip", ":yis", ":yodawg", ":yolandi", ":yoshi", ":youcanleave", ":yougirls", ":youknowit", ":youmad", ":youngdumb", ":youngtarnation", ":youregay", ":yourgf", ":yourn", ":yousuck", ":youths", ":youtried", ":youwouldntgetit", ":ytho", ":yuck2", ":yuck3", ":yup", ":yvette", ":z", ":zeddance", ":zelda", ":zero", ":zeroviews", ":zoltan", ":zombbald", ":zoombrows", ":zoomer", ":zorak", ":zorro", ":zsnap", ":zuck", ":pocky", ":tehrei", ":classic2", ":combo", ":umhi", ":chefkiss3", ":bella", ":lul", ":toesuck", ":highlysus", ":fatcody", ":robosoprano", ":savant", ":backflip", ":2in1", ":biglol", ":moneyplease", ":robbedbyape", ":pray", ":pikaahegao`", ":drugs3", ":butt3", ":catbutt", ":asshmm", ":feelit", ":based", ":toothfairy", ":flute", ":noot", ":noot2", ":pingumock", ":pinguspank", ":bbc", ":wario2", ":uchihapepe", ":fusion", ":pathetic4", ":cringe4", ":4k", ":4k2", ":8k", ":4k3", ":doitagain", ":lipbite", ":bait2", ":neat", ":help2", ":frasier", ":brule", ":laugh", ":fishrun", ":django", ":fuck", ":weirdge", ":amaze", ":henrygrin", ":zzz", ":slowblink", ":robopicasso", ":chad2", ":tswift", ":cope", ":ineedtopoop", ":fishdickfuck", ":bignut", ":quicknut", ":fuckbobby", ":bropls", ":toesuckin", ":toesuck2", ":data", ":toes", ":tyler", ":splain", ":noregrets", ":ayyyshawty", "::maybe", ":maybe", ":makeitworse", ":full", ":fatspin", ":fatspin2", ":moepepe", ":kek5", ":eyecontact", ":eyecontact2", ":interesting", ":interesting2", ":shrekt", ":arteezy", ":kekbomb", ":fax", ":k3", ":covid", ":bropls2", ":catcody", ":catcough", ":codycat", ":wholesquad", ":ff14", ":stupidbitch", ":dale", ":stop3", ":hank3", ":hoss2", ":standoff", ":noblink", ":robobike", ":twinning", ":catchorus", ":roboglow", ":mjhyper", ":notaphase", ":neekglow2", ":catglow", ":hey2", ":loudshock", ":reaper", ":codycoom", ":rocketman", ":elltchyper", ":imthinkin", ":TOE", ":magnify", ":madaf", ":zoombrows2", ":lookingdown", ":excuseme", ":fastcry", ":aaa", ":crypout", ":wail2", ":sweating2", ":gentlyholds", ":riverofsads", ":wantcry", ":ska", ":magnify2", ":goatsee", ":cobraglow", ":cobrahyper", ":practice", ":bigyell2", ":neekhyper", ":kekwglow", ":iwish", ":weeb2", ":cobraglow2", ":cummies", ":batman2", ":melon", ":pppig", ":sweetdreams", ":hugs", ":catgun", ":bless", ":whatif", ":nicecock", ":darkboo", ":dumper", ":tear", ":phone", ":milkshake", ":paulyv", ":bgglow", ":lahee", ":embarrassment", ":ignoreme", ":IGNOREME", ":roboner", ":dale2", ":sniff", ":chefpepe", ":jam", ":buggin", ":notallcops", ":pepeswing", ":robonerer", ":cybermj", ":future", ":agatha", ":croble", ":pepepat", ":crobleglow", ":stupidbitch2", ":pepereally", ":pepekek2", ":memory", ":flcl", ":lobe", ":acab", ":catbrush", ":ltcglow", ":member", ":luigistare", ":imcool", ":stu", ":pepejam2", ":lipbite2", ":yeahboi", ":birt", ":cumdog", ":megamind", ":imcool2", ":shock", ":haha2", ":sungun", ":cuties2", ":nottrue", ":microphone2", ":coontailjesus", ":stopme", ":sk8", ":answerme", ":pathetic5", ":woody2", ":stonecold", ":cringedept", ":gun2", ":jg2", ":kek6", ":timepassing", ":humanityrestored", ":badopinion", ":notaphase2", ":peacock", ":scarlet", ":communism", ":now", ":homura", ":elvira2", ":kekwwalk", ":ready2", "::malarkey", ":shh", ":secrets", ":tarnation4", ":popcorn4", ":kraft", ":gawrsh", ":dance31", ":sad2", ":mathanswer", ":scream2", ":spidermen", ":7spidermen", ":5spidermen", ":thor", ":dany", ":animemj", ":cobrahehe", ":souptime2", ":animuu", ":laughcry", ":pepeplead", ":fmape", ":robopog", ":alf", ":stare9", ":frostedbutts", ":squirt2", ":cap", ":jeez", ":dolphingun", "::thonk2", ":ff7", ":woahmama", ":hugs2", ":pocketsand2", ":why4", ":super", ":fan", ":deegag", ":system", ":yaskween", ":count", ":heavybonk", ":ruok", ":higher", ":knifemoomin", ":knifemoomin2", ":peaceful", ":slut2", ":slut3", ":bread2", ":tfmoomin", ":angy", ":fancymoomin", ":airfryer", ":kanyeturn", ":isleep", ":realshit", ":superfinalcroble7", ":crobletwin", ":flex5", ":MODS", ":yokotaro", ":eddy", ":dorks", ":butwhy", ":weirdge2", ":cop", ":problems2", ":interesting3", ":goahead", ":wookwizard", ":imright", ":cheems", ":crabrave", ":4pm", ":solong", ":had", ":pogo", ":bellamfw", ":booba", ":booba2", ":periodt", ":dogfart", ":applecat", ":kiss2", ":blah", ":religion", ":bingusblink", ":glare2", ":bingus", ":shitpost3", ":hah", ":mcpepe", ":pepepray", ":thirsty2", ":doomhauer", ":codysnicebeard", ":reallyhigh", ":andrewmfw", ":beaker", ":meep", ":shudup", ":tryhard", ":MODS2", ":bigyell3", ":hugs3", ":sisqo", ":changeplaces", ":ricardour", ":notsorry", ":rave2", ":epic", ":strong", ":lfg", ":BRUH", ":neverenough", ":enough", ":ha", ":ewdavid", ":ew3", ":cantbelievethis", ":thinking", ":hattip4", ":explaining", ":coolair", ":indeed2", ":leatherface2", ":ehrgeiz", ":frogwithhat", ":frogwalk", ":amcry", ":lfg2", ":https://i.imgur.com/yM9rNoP.gif", ":shroomjak", ":max", ":hurt", ":fishyell", ":waill", ":frogham", ":loading", ":slamham", ":frogger", ":lisa2", ":peas", ":isay2", ":ripped", ":blink5", ":childclown", ":what2", ":marceline", ":computer3", ":eyebrows4", ":bite2", ":nice3", ":dance32", ":gottapoo", ":tinkle_toes", ":feelsgood", ":santapog", ":yotsuyu", ":flavortown", ":bezoskink", ":dag", ":hmph", ":corntime", ":hmmmaybe", ":shyhi", ":ffegg", ":pussyassbitch", ":winslow", ":winslow2", ":umhello", ":colton", ":catsaidno", ":goodenough", ":cmon3", ":dudejustchill", ":jazzhands2", ":bongo", ":catpat", ":catrun", ":golbat", ":thinkfast", ":speedroll", ":chickenroll", ":dance33", ":gachibass", ":gachibass2", ":gachipet", ":gachimen", ":gachiflexparty", ":gachifight", ":edthumb", ":myaa", ":vr", ":cookiedance", ":scoob", ":ahegaojesus", ":ahegaojesus2", ":ahegao3", ":mm4", ":supernut2", ":aliensanta", ":buttthonk", ":lies2", ":thanos", ":nobodycares2", ":mood2", ":roachspin", ":hotdogspin", ":peaceout3", ":hamjam", ":fishjam", ":knucklespin", ":lmaoo", ":chairspin", ":goosejam", ":polespin", ":reneesmee", ":shaking", ":fishwalk", ":fishdance", ":skeletonparty", ":fishjump", ":fishdance2", ":moisturizeme", ":blood", ":hazzy", ":pikadick", ":buffet", ":summer", ":cunt2", ":cunt3", ":dance34", ":bsdphish", ":florindo", ":imhere", ":mock3", ":shocked8", ":chefkiss4", ":dry", ":rawrpp", ":bazongas", ":bigtittyjames", ":scienceparrot", ":heybb", ":ceilingparrot", ":trolol", ":bigdick", ":jesusballin", ":trollspook", ":cope", ":feelinit2", ":coffee2", ":punchyou", ":kittyheart", ":killmenow", ":yunggravy", ":shocked9", ":oh", ":gaytangent", ":mrmime", ":axew", ":salute", ":americansalute", ":muricansalute", ":awaken2", ":renesmee", ":peeposmoke", ":lookingdown2", ":itsfine", ":what4", ":gigachad", ":forever", ":approed", ":trollspook", ":butwhy2", ":look", ":ohno3", ":hii", ":nopers", ":trolol", ":cope2", ":pizza", ":pedo", ":wharf", ":madnezuko", ":itwasfake", ":dgenerationx", ":suckit2", ":pupperchino", ":mindblown3", ":hello3", ":recycle", ":ballin2", ":sus2", ":bratwurst", ":prettygood", ":councilno", ":googleit2", ":ripped2", ":kanyejoker", ":handwalk", ":nrawrez", ":noodles", ":narutorun", ":howboutno", ":nono3", ":dankies", ":onit", ":fatality", ":ohhoney", ":love2", ":kippyjam", ":p0ns", ":shooketh", ":robolense", ":kippyalien", ":wheeze", ":mieruko", ":roborun", ":nightrobo", ":watching", ":blinkfern", ":kekpoint", ":roboglow2", ":mesarawr", ":flapple", ":appletun", ":leedle2", ":toad2", ":iwillendyou", ":queefmilk", ":spacedog", ":salute2", ":ivermectin", ":goblin", ":leash", ":bzzz", ":hotcheetos", ":yell3", ":isaidnow", ":goomba", ":glasses", ":711raid", ":wowbutno", ":clop", ":celeryman", ":avocado", ":bcizzo3", ":avocado2", ":verysober", ":hurry", ":derpup", ":engage", ":dance35", ":dance36", ":excite2", "::callme", ":callme", ":pathetic6", ":laugh2", ":teatime", ":t2", ":chilis", ":handup", ":handdown", ":g4", ":g2", ":g0", ":stuffed", ":offmyscreen", ":bingusshh", ":difficult", ":notlistening", ":oatmeal2", ":nataliemfw", ":alanis", ":kms9", ":pogrill", ":drool4", ":wumbo", ":ascended", ":hatetosee", ":bluewaffle", ":guy", ":https://i.imgur.com/1DZYLZd.jpg", ":Koga_pokemon", ":gonnaeatdatass", ":delet4", ":shimmy", ":hentai", ":litecoin", ":stare10", "::cum", ":alien", ":slug", ":nicksmash", ":1v1", ":6eyes", ":gigacody", ":storm", ":sob", ":chodemode", ":jokerlaugh", ":kekno", ":yum", ":pardoneme", ":mars", ":more", ":nategun", ":toki", ":mila", ":horgan", ":donut", ":sploosh", ":meowdy", ":bathtime", ":smh5", ":madhank", ":skeleshake", ":ape3", ":spongepls", ":ahegaod", ":shitpostofshitposts", ":morningjuice", ":ohjam3", ":ohjam4", ":ohjam5", ":texans", ":headbanger", ":kronk", ":kroger", ":chuckle", ":lightsaberpepe", ":daddy", ":rarertz", ":cumhat", ":hydrate", ":squint7", ":toki2", ":egging", ":mortalkobra", ":mlp", ":pizzahut", ":tunapizza", ":dozes", ":huckleberry", ":hold", ":guitar", ":evenless", ":paris", ":crying3", "::shh2", ":shh2", ":rimshot", ":ohma", ":itsnothelping", ":gtfo", ":turdnugget", ":hotdogspin2", ":cringe5", ":sovietrobo", ":mutahar", ":mutahar2", ":handled2", ":santaart", ":fistpump", ":fistpump2", ":fistpump3", ":wow6", ":ew4", ":steveachieved", ":yw", ":flippinout", ":staticair", ":tokenbsd", ":toast", ":queefmilk2", ":ohhh", ":arthurdog", ":letssausage", ":MODS3", ":sonic", ":crylol", ":holiday", ":holiday2", ":rollinginitiative", ":dylan", ":jolie", ":hyb", ":eth", ":catgun2", ":widerrobo", ":pepedance2", ":pepocheer", ":mspepe2", ":sticker2", ":onyonring", ":onionring", ":us", ":mouth", ":exp", ":fortnite", ":fortnite2", ":fortnite3", ":fortnite4", ":feisty", ":snakedance", ":popenope", ":air_in_the_gym_like", ":hairofthedog", ":minecraft", ":burrito", ":fangirl", ":kirbydance", ":skeletonpls", ":skeletonpls2", ":skeletonhyper", ":sosnowy", ":zicam", ":mcdonalds", ":metaverse", ":sunglasses", ":winslow3", ":winslow3", ":catgun3", ":ignored", ":rock2", ":ruin", ":myfriends", ":whydidyou", ":cumhands", ":cum2", ":poisonivy", ":dickhead", ":pepecoffee", ":imout", ":imout6", ":hecums", ":k", ":yea", ":secretsanta", ":n8pog", ":tiptoe", ":goosewalk", ":santaratjam", ":gunther", ":full2", ":garfield4", ":robomario", ":robothanos", ":ssrobo", ":humanity", ":creepin", ":victory", ":greatsuccess", ":sortit", ":bingbong", ":itsworking", ":boner", ":paul", ":nyan", ":fuming", ":beanbong", ":rawrcreep", ":rawrbust", ":n8nap", ":creeper", ":scroll", ":addict", ":mindwar", ":froth", ":williamnapfin", ":catgun4", ":gaslight", ":confirmed", ":catexplode", ":broccoli", ":pointing", ":poodance", ":byedog", ":midgar", ":noted", ":pleading", ":beer", ":shapes", ":ambien", ":ukkyfood", ":p", ":lmfaooo", ":njuarezzz", ":fiashass", ":diamondhands", ":kermitgun", ":laugh3", ":notbad", ":shitpost2", ":dead2", ":elltcgreed", ":thatbag", ":makemoneymoney", ":cockadoodledoit", ":twts", ":twss", ":imgonnagetyousucka", ":nftmoney", ":sleepsonthesun", ":phil", ":done", ":sniff2", ":science", ":stun", ":babystorage", ":roachdance", ":suicide2", ":kiplit", ":omgwow", ":suicide3", ":dubious", ":lipjak", ":babyknees", ":***", ":speak", ":dance37", ":cattongue", ":imsorry", ":dobrik", ":blink6", ":dogstare", ":ohdeer", ":pizzarolls", ":pizzaroll", ":hi5", ":wuh2", ":scrollup", ":keke", ":fester", ":rly", ":squirtlejam", ":ohjam6", ":army", ":allgedly", ":breathe2", ":rawr2", ":unamused2", ":whore", ":bonedance", ":I", ":ohyes", ":chill2", ":mug", ":unamused3", ":fairlyodd", ":enjoyer", ":dunkedon", ":maidens", ":cumhands2", ":fbi", ":nut2", ":snake2", ":manz", ":naruto2", ":yougotthis", ":debunked", ":ohnoda", "::sleepyhoney", ":cobravictory", ":hi6", ":bgshower", ":bgbrush", ":heatheryell", ":puffdade", ":hell", ":nuggies", ":rules", ":godrick", ":fingergun2", ":canofworms", ":boomerrave", ":dontforget", ":hereforever", ":creepy", ":formetopoopon", ":descend", ":rico", ":rico2", ":fly", ":robogump", ":KEKWbgmfw", ":robopelosi", ":KEKWrobo", ":mbdtfrobo", ":bsdefeat", ":yellowcard", ":yellowcard2", ":hornytown", ":vegan", ":hornybeans", ":indeed3", ":horndog", ":1000miles", ":cuddle4", ":moan", ":pointing2", ":pointing3", ":kiplit2", ":pointing4", ":hatman", ":aliens3", ":marijuana", ":pathetic7", ":O6", ":comment", ":oscarslap", ":oscarslap2", ":slap4", ":serperior", ":tired2", ":tired", ":bruv", ":fuho", ":eatingdoge", ":eatingdoge2", ":tuck", ":checksout", ":advice", ":fbi2", ":blush4", ":kms1", ":nft", ":reprogram", ":boobstare", ":dickstare", ":cope3", ":comfy", ":sizequeen", ":imcute", ":job", ":stareup", ":fallingdown", ":cool2", ":slap5", ":scooter3", ":hair", ":anime", ":chicken", ":coffee3", ":beautiful2", ":coffee5", ":greta", ":chunk", ":handshake", ":business", ":rosie", ":fridge", ":jeans", ":oil", ":knockknock", ":poop", ":booba4", ":poki", ":poop2", ":smart4", ":breakdance", ":king2", ":family", ":rain2", ":love3", ":bed", ":truegoi", ":cantseeme", ":youcantseeme", ":pleaseclap", ":chikayo", ":animejam", ":mason", ":aligator", ":animehyper", ":betrayal", ":JAMMERS", ":jammers", ":hedgehog", ":hedge", ":bg", ":bgru", ":nut3", ":hello4", ":girugamesh", ":kipglow", ":tikishow", ":tikis", ":tikishow2", ":tikishowass", ":tikiwish", ":piss", ":sonohead", ":howlit", ":rawrlax", ":rawrpole", ":bsdglare3", ":nobg", ":hurd", ":buckethead", ":zazu2", ":zazu", ":bgmfw2", ":asian_slurp_noises", ":howlewuh", ":soupfrog2", ":cats", ":erpathetic", ":slowclap", ":praise", ":budden", ":hatwobble3", ":flargenstow2", ":maddisrespect", ":droop", ":doit3", ":sinister", ":pepepp", ":ants3", ":kanyesonic", ":muc", ":tanbitch", ":catJAM2", ":heard", ":honeybadger", ":magnets", ":struttingleo", ":trollin", ":hearteyes2", ":cry4", ":faded", ":tada", ":gj", ":celeryman2", ":pepebooba", ":jam2", ":nobitches", ":nobitches2", ":goodsoup", ":simp2", ":pepedonger", ":bcytd", ":squat", ":kms10", ":bitchwtf", ":wow-what", ":wowwhat", ":getred", ":mcworld", ":airhead", ":marnin", ":scanners", ":headexplode", ":airquote", ":airjoy4", ":airmfw", ":glazed", ":teatime2", ":coomer", ":thesickoweneed", ":starechamp", ":binguspet", ":lion&amp;betrayal", ":drink2", ":gachiroll", ":ponstare", ":source", ":geoduck", ":geodude", ":2head", ":halfpipe", ":apeinside2", ":member2", ":morbintime", ":patgasm", ":nug", ":laughingairs", ":jarjar", ":andrew", ":verynice", ":ponstare2", ":dance38", ":shrimp", ":mommymilkerspepe", ":vote", ":tableflip", ":ponspeak", ":showoff", ":ditto2", ":darkmoongoths", ":headscratch", ":evilpepe", ":piccolo", ":shittydad", ":zamn", "::airarmedpenpenamericaboobaleg", ":airarmedpenpenamericaboobaleg", ":penpenthefrog", ":actinup", ":ooooooo", ":ok3", ":souptime3", ":nickpoint", ":peek3", ":surprise", ":fuckyeah2", ":fuckyeah", ":mikohello3", ":dancedog", ":hangry", ":galaxse", ":sickos", ":kiplit3", ":tinylife", ":pikapray", ":pray2", ":db", ":sussycat", ":MODS4", ":pianocat", ":pianocat2", ":eggyell", ":eggyell2", ":dietweed", ":bowserlaugh", ":punch2", ":0.0", ":hgd", ":castingcouch", ":gif", ":boop2", ":headpats", ":monkeypox", ":ken", ":deadinside5", ":wolfjak", ":rusadness", ":fwend", ":trumpsteak", ":dancedog2", ":oven", ":sory", ":monke", ":means", ":nolies", ":wood", ":ripbozo", ":bozo", ":heyguys", ":poke1", ":airjam", ":bsdgroove", ":whatinrawrnation", ":excuseme2", ":spideyrod", ":whoa2", ":neo2", ":whoa3", ":vibe", ":papa", ":tikigroom", ":soupdreams", ":loafthink", ":widevibe", ":raging", ":howlerap", ":danceboye", ":genie", ":yogaflame", ":celebrate", ":biggiebsd", ":rarapriapus", ":zooted", ":stardew", ":lost", ":hotdag", ":tikicamp", ":frogsplash", ":bannedonthesun", ":gitgud2", ":run", ":ratspin", ":runs", ":hapsburg", ":neat4", ":shortcat3", ":coffeecat", ":dessertcat", ":bcytdbunny", ":aircheat", ":logoff2", ":donowall", ":nope7", ":stank", ":imwithstupid", ":jimmy", ":tmb", ":yell4", ":success", ":loaftc", ":aware", ":gopiss", ":slorp", ":shehulk", ":roomierun", ":roomiezoomie", ":googling", ":commitdie", ":pepemilk", ":rly2", ":movebitch", ":LMAO", ":coffeepot", ":rattleem", ":walk", ":scumbagpenpen", ":ohmy", ":toebeans", ":tippytaps", ":dogehug", ":zahnfeet", ":hoglog", ":colortortoise", ":harvest", ":k4", ":bananacatdance", ":meanie", ":panfrog", ":raged", ":stew", ":TOE2", ":gangster", ":wook2", ":youwannadab", ":cobrafeet", ":kippyfeet", ":hidden", ":fucku", ":offer", ":myeyes", ":monkeywalk", ":dance39", ":decafdays", ":dance40", ":source2", ":wuh3", ":charlie", ":soupmode", ":nocheese", ":stimulants", ":skeledance2", ":sighs", ":greetings", ":itsuǝʇuǝʌǝs", ":bilbo", ":kippycat", ":ptsd", ":slimjim", ":devils", ":dodgeball", ":hpyed2", ":bestmovieofalltime", ":webmd", ":pumpkincat", ":skeletonjam", ":fart2", ":json", ":joker2", ":edgesadge", ":moneypls", ":gachibeer", ":cumbia", ":hoagiegao", ":pogs", ":fucku2", ":acid", ":hating2", ":monch", ":lazy", ":turkeycat", ":urbutt2", ":runhole", ":omw", ":hello5", ":fightme", ":rawr3", ":walk2", ":gm3", ":daily", ":monch2", ":speedwalk", ":cummyworm", ":dance41", ":peachstare", ":smokey", ":deadinside6", ":ty", ":pepepokemon", ":boii", ":banjo", ":entrance", "stevewtf", ":doyourthang21", ":hellocat", ":mindblown4", ":happymeal", ":roger4", ":splat", ":grouptherapy", ":fuckyousay", ":sza", ":beanslice", ":fadedthanaho", ":mukbang", ":pepecowboy", ":logfrog", ":madden", ":robocop2", ":pass", ":mxe2", ":mood3", ":tipshat", ":hat", ":deck", ":gn", ":catbong", ":imout7", ":christmas", ":waifu", ":cops6", ":banned", ":noonecaresair", ":christmasmiracle", ":music", ":dejj", ":notlikethis", ":cereal2", ":robonertc", ":youdied", ":chrimbus", ":uuu", ":dva", ":thccreep", ":bcizzoxmas", ":cybaman", "::djcat", ":djcat", ":what5", "::ot", ":toke", ":salute3", ":scanned", ":kek7", ":marge2", ":hi7", ":volturi", ":franco", ":wyd", ":scared", ":goddamnit", ":lal", ":lal2", ":construction", ":charmaccry", ":bigbird", ":gasp2", ":mrass", ":wee", ":ye", ":cumtruck", ":milk", ":milk2", ":jfs", ":sir", ":chocies", ":earboy", ":2much", ":uwu", ":smug2", ":ice", ":tothecloud", ":2thecloud", ":shame2", ":parm", ":bendy", ":murder", ":ceo", ":zomg", ":jox", ":riker", ":yo", ":pcrow", ":whoasked", ":gn2", ":shocked10", ":love4", ":airfryer2", ":mouth2", ":orb", ":eye", ":pepegalick", ":mouth3", ":eye2", ":mouth4", ":llamabsd", ":llamabsd2", ":dam", ":goatsamee", ":psipouch", ":airgenie", ":watchit", ":reversemouth3", ":toki3", ":angrydooting", ":owo", ":woooo", ":psiscream", ":synergy", ":itsaplant", ":catnikk", ":bcizzoman", ":cumparty", ":cowboyy", ":doggie", ":reverseapplecat", ":pasta", ":standspin", ":sitandspin", ":loaff", ":KEKwait", ":humpin", ":sb", ":sb2", ":sb3", ":sb4", ":#1dad", ":happypsi", ":banhmi", ":mail", ":wellshit", ":yay", ":coastin", ":sickgains", ":sleepparalysisdemon", ":me", ":gm4", ":cargrin", ":excite3", ":colemak", ":vibecheck", ":caw", ":notsmart", ":tldr3", ":noidontthinkiwill", ":snackmail", ":robots", ":emmashot", ":bitchwtf2", ":businessdoggie", ":penpenshot", ":widepsi", ":both2", ":idiot", ":this_house_is_now_clean", ":rage4", ":bobbydazzler", ":p0ns2", ":p0ns3", ":grover", ":omgwut", ":oof3", ":scramshot", ":geeked2", ":videotapes", ":iamthenap", ":goofy3", ":hyb2", ":p0ns4", ":airvibes", ":dancebros", ":airjoint", ":tikitokes", ":cuddlepuddle1", ":cuddlepuddle2", ":cuddlepuddle3", ":bg1", ":cuddlepuddle4", ":puzzlebros", ":cobracuddle", ":bros", ":bromunch", ":bassheads", ":alys", ":tikitorch", ":wiggie", ":wiggieass", ":p0ns5", ":iowa", ":highfashion", ":milkers", ":homies", ":pweepo", ":santas", ":bigbutts", ":walk3", ":happy3", ":joy", ":bgsleep", ":pepegun3", ":nathanfielder", ":lizpathetic", ":scram2", ":scram3", ":tacoma", ":mento", ":static", ":die", ":imadeitup", ":madeitup", ":shook2", ":wideboris", ":hattime", ":emotedepot", ":bro2bro", ":workworkworkworkwork", ":itsaight", ":classic3", ":bananacat", ":toewash", ":shrekfu", ":glonky", ":pepecum", ":scramclown", ":chomp", ":imwet", ":filetofish", ":jigglin", ":hamfloss", ":thrilled", ":shreked", ":bgmeowwolf", ":mcbg", ":jinx3", ":toasted", ":AAAA", ":munch", ":point4", ":frust", ":upchatbub", ":monkeycircle", ":hurting", ":nicecock2", ":yo2", ":love5", ":mathismath", ":clown3", ":meowdy2", ":sadp0ns", ":deems", ":modding", ":avocadocat", ":mario2", ":mctime", ":peperide", ":pepepeace", ":pee", ":cake", ":stirpot", ":grindin", ":thumbsup3", ":yesi", ":d4", ":pee2", ":nothing", ":soup", ":kiss3", ":preparethyself", ":wank", ":concern2", ":gasp3", ":eye3", ":eye4", ":mouth5", ":patrick", ":eye5", ":mouth6", ":eye6", ":mouth7", ":mouth8", ":mouth9", ":eye7", ":eye8", ":drip", ":freedom", ":stressed", ":icant", ":reignin", ":pathetic8", ":tangy", ":awake", ":limes", ":speedracer", ":moneyrain", ":challenger", ":retard", ":cummies2", ":myhug", ":slur", ":dontneedit", ":succ", ":dotdunk", ":itmoved", ":confused", ":allofit", ":approved2", ":guilty", ":sis2", ":d42", ":gn3", ":loveit2", ":loveit3", ":loveit4", ":loveit1", ":loveit5", ":adhd", ":dance42", ":shock2", ":smile9", ":cool3", ":mayo", ":tf2", ":fumar", ":nut5", ":panic2", ":unless2", ":resinhits", ":goon2", ":dotscat", ":laughinggirl", ":thunkingbg", ":grandma", ":redheadguy", ":fast", ":wrong2", ":fightme2", ":squard", ":nomnom", ":69man", ":bamboozled", ":score", ":ohno4", ":hell_yeah_brother", ":dickgun", ":workdone", ":nostep", ":clap7", ":hi8", ":dance43", ":dawg", ":dawg2", ":trumpshot", ":whitewidow", ":fedora", ":wail", ":dontuwu", ":rings", ":wimdy", ":nod5", ":thisbig", ":hoodedair", ":uni1", ":uni2", ":uni3", ":uni4", ":sophie", ":pizzaman", ":psibowfinger", ":garfass", ":flag", ":weenie", ":grinch", ":dealwithit2", ":help3", ":fun", ":pete", ":pete&amp;pete", ":peteandpete", ":rawrgrin", ":studio", ":toobad", ":happypsi2", ":gandalf", ":bilbo2", ":nope6", ":thumb", ":goodmorning", ":sciencebitch", ":nosalt", ":howlecheese", ":dealwithit3", ":oprah2", ":kakamafallen", ":angelneek", ":pukedog", ":motionfiled", ":notweed", ":thisbig2", ":bfab", ":happy4", ":lilcorner", ":penis", ":pobrecito", ":hellowo", ":bigboom", ":autistichello", ":youcanhaveit", ":flourishing", ":what6", ":jumpscare", ":dosomething", ":justdoit", ":acidspray", ":froggerer", ":froggerest", ":mane", ":staind", ":fallen", ":mclovin", ":myleg", ":howdy", ":spruce", ":edward", ":grazed", ":gentlemen2", ":saddam", ":shun", ":magicwords", ":sneaking", ":blondesrule", ":bouncyblonde", ":korn", ":yougetacar", ":korn2", ":finally", ":blackspot", ":drywall", ":processing", ":scree", ":yeahbaby", ":dance44", ":waiting3", ":crying4", ":toodamn", ":stomp", ":tikibacon", ":dance45", ":curtsy", ":youreinone", ":milkman", ":thinking3", ":fullspectrum", ":pout", ":quicksilver", ":dance46", ":knuckles", ":flourishing2", ":ab", ":zamn2", ":looking2", ":looking3", ":looking4", ":yowl", ":dance47", ":ghostwolf", ":mongs", ":stanky", ":stealmeme", ":forcefield", ":stiffarm", ":scramble", ":kermit", ":jot", ":imgonna", ":imgonna2", ":powerscombined", ":dontmatter", ":grumble", ":shakeitbaby", ":powerscombined2", ":hurtingotherpeople", ":casperpog", ":taunt", ":ihateyou", ":dsfargeg", ":psicorn", ":kink", ":candypsi", ":fuego", ":frogdance", ":dorito2", ":samehat", ":samehat2", ":samehat3", ":samehat4", ":pence", ":toeburger", ":elevatedair", ":rapeture", ":rapture", ":margegasm", ":corndog", ":kippyclown", ":lethimcook", ":turkeyRawr", ":jmoney", ":frogthirst", ":soundsgay", ":hbd2", ":dance49", ":purple", ":frogspin", ":fishspin", ":essspook", ":garbageday", ":feet2", ":inspec", ":walter", ":airchz", ":white", ":dance3", ":dude", ":redflag", ":givepizza", ":opticalillusion", ":absurdism", ":handsonmyknees", ":tdtibliibid", ":shadowthehedgehog", ":shadowthehedgehog2", ":gonnabustdatass", ":iamtired", ":iamtired2", ":slurms", ":imagine", ":pickle", ":kalso", ":kickthebaby", ":nowdrink", ":yeehaw", ":huh3", ":partyrawr", ":itsafraid", ":petesbrotherpete", ":notme", ":ineed", ":spidey", ":spidey2", ":birdo", ":peer", ":moonkin", ":boomkin", ":nou2", ":gimme", ":rawrwork", ":growup", ":fard", ":podracing", ":oop", ":glonkykong", ":kipyelp", ":headempty", ":dickdrop", ":imgonna3", ":beardstroke", ":beardflick", ":here", ":takethis", ":thundercougarfalconbird", ":icame", ":tinykeanu", ":pilgrim", ":isee", ":isee2", ":sandevistan", ":deadarm", ":breakingthru", ":multipass", ":headshot", ":alberto", ":alright", ":alright2", ":ppap", ":thinkingcap", ":please", ":pleasetc", ":tap", ":lyin2", ":fixit2", ":duckjam", ":ducks", ":croissant", ":kippy2", ":pig", ":sticker", ":thumbstab", ":bigkip", ":resolved", ":herewego", ":hamies", ":frankie", ":slap6", ":catcat", ":moathcake", ":ranch_it_up", ":vanish", ":dopamine", "::truckdabes", ":shaking2", ":mob", ":batty", ":dafoe", ":rainblood", ":thunkingkippy", ":glitchyglizzy", ":triangles", ":dumper2", ":goodnews", ":dafoe2", ":vivekstaind", ":terry2", ":quenched", ":help", ":smile", ":yuck", ":soupspin", ":https://i.imgur.com/Km3xG0f.png", ":https://media.discordapp.net/attachments/1030550509255413770/1182245479111741450/skaven-rat.gif", ":cumpizza", ":strawberrycat", ":gg", ":thee", ":the", ":nod3", ":oops", ":airyay", ":snark", ":bcytdshot", ":sadcum", ":stoppls", ":kedi", ":mcblaster", ":biglentil", ":leatherface3", ":ramimalet", ":ikeacustomerservice", ":2muchdummy", ":fishass2", ":moonwalk", ":penis2", ":air", ":aircringe", ":credits", ":chipi", ":indicabro", ":oli", ":dab5", ":christmascat", ":lisaweed", ":pepeglizzy", ":merryfishass", ":entrance2", ":reward", ":penpenyay", ":doublereacharound", ":fpov", ":thisbitch", ":yeboi", ":pizzatime", ":tubgirl2", ":penpenyay2", ":chrimbus2", ":pathetic9", ":chomchom", ":nohotdog", ":shoveit", ":ditto", ":brushteeth", ":peteshh", ":yee3", ":zero10", ":deadinside7", ":samuel_", ":forchina", ":https://i.imgur.com/Mbya2dF.jpg", ":bigcat", ":mychild", ":rawrbutt", ":rizz", ":cutie", ":pastabrain", ":rawrdip", ":fridshot", ":flippintongue", ":spicysmile", ":fufap", ":mypart", ":shrug4", ":shidded", ":https://i.imgur.com/cjUkf0N.png", ":ICANT", ":phones", ":hurryplease", ":camelguy", ":pib", ":ouch2", ":wheezinthejuice", ":pimppy", ":plannin", ":ratattack", ":ronaldspin", ":fishdip", ":tubgirl3", ":nobitches?", ":badthings", ":gun3", ":sonic2", ":flipzamn", ":peer2", ":frogspin2", ":frogbutt", ":howle4k", ":frenchrawr", ":dandecheers", ":dickfetish", ":bitches", ":spongecry", ":correct", ":smart5", ":frosty", ":broke", ":)", ":glare3", ":skinacat", ":asian", ":facts", ":ifhedies", ":murderousmood", ":khole", ":doghouse", ":sec", ":felony", ":illegal", ":spank", ":jmoney3", ":greed", ":react", ":fishbutt", ":gush", ":imbusy", ":kipthot", ":frogtaint", ":hypnofrog", ":nailedit", ":andyondrums", ":eye9", ":ramen2", ":heylisten", ":icantread", ":bigyoshi2", ":returntheslab", ":violin3", ":notdoingit", ":busy", ":imgood", ":asian2", ":surrounded", ":surrounded2", ":prolapse", ":peterknee", ":peeing", ":deepfriedspicy", ":deepfriedspicy2", ":cornbliss", ":bread3", ":corn", ":lovemycat", ":shock3", ":orwhat", ":her", ":chest", ":nice4", ":frogwheel", ":wellwellwell", ":wellwellwell2", ":dance50", ":pouroneout", ":https://vidble.com/rIgL849oUS_med.jpg", ":gooning", ":struts", ":jail", ":x", ":kippythor", ":knifedick", ":butt4", ":guessilldie", ":ladybird", ":gang", ":gang2", ":swoon", ":booba3", ":0days", ":2000yearslater", ":2hourslater", ":REE2", ":REE4", ":WAP", ":absolutelydisgusting", ":actually", ":4spidermen", ":aintreading", ":aireat", ":airjoy", ":airjoy2", ":airnap", ":airpog", ":airshock", ":airyum", ":airquotes", ":allegedly", ":always", ":angery", ":angrygay", ":annoy", ":annoy2", ":arthur", ":mm", ":spicytheexplorer", ":exactly", ":specialdelivery", ":rough", ":gay3", ":onfleek", ":kazoo", ":alltheregret", ":rawrsignaling", ":ooweeoo", ":mlady2", ":cum", ":high12", ":tajin", ":angel", ":buffcat", ":unfuckable", ":tired3", ":holemer", ":holemer2", ":deadinside8", ":fishbj", ":crackfila", ":crackfila2", ":crackfila3", ":vibin", ":no", ":goblin2", ":lies3", ":fuckyoufaced", ":fucku3", ":clown4", ":catoe", ":funcenter", ":2ndcumming", ":shitdick", ":imhim", ":bush", ":fishrawr", ":myson", ":french", ":rdjgrin", ":rdjgrin2", ":truffleshuffle", ":newport", ":nvm", ":ihavefire", ":catsmile", ":shrimpjam", ":blink7", ":ok4", ":snort", ":itstank", ":glizzyface", ":listen", ":freddy", ":dap", ":pcp", ":boo2", ":pedro", ":gudetama", ":madpete", ":mikublunt", ":widekippy", ":widerkippy", ":us2", ":turtletime", ":littlebeet", ":validate", ":blush1", ":blush", ":blush2", ":sophie2", ":moisturized", ":tmnt", ":https://i.imgur.com/tcKLHPa.gif", ":jojo2", ":jojo", ":catlmao", ":catwave", ":officerdown", "::ruehigh", ":hyb3", ":inconceivable", ":erect2", ":amen", ":pastafall", ":bgrinch", ":tarnation5", ":smile10", ":drake4", ":moisturized2", ":spiritbomb", ":hegel", ":pegging", ":gun4", ":gun5", ":gun6", ":gun7", ":squad2", ":costanza", ":soupfrog3", ":kline", ":notes2", ":waifu2", ":eyetwitch", ":lockin", ":bacon2", ":bacon", ":lore", ":magnify3", ":bow", ":asshole", ":enchantment", ":dball", ":pizzatime2", ":kerbal", ":metime", ":widetarnation", ":cuh", ":boi4", ":shave", ":shame3", ":think", ":nod6", ":thickandpulpy", ":shrekgrin", ":smoke7", ":endure", ":validate2", ":goonchair", ":dunkbros", ":youradventurebegins", ":thestruggle", ":rawrnohandchecks", ":math4", ":cleavage", ":humanass", ":doomcum", ":catdap", ":wya", ":dance51", ":tech9", ":curious", ":breadstick", ":dragonball", ":brainworms", ":organs", ":dance52", ":wtfpete", ":mhm5", ":CAUGHT", ":jordan2", ":hi4", ":itstime", ":penjamin", ":owo7", ":fembot", ":nn", ":woof", ":shocked11", ":goonfathered", ":pepestank", ":rice", ":fallen2", ":blinkies", ":jackoff", ":loggingon", ":wendys", ":fioc", ":twohotdogs", ":goonmorning", ":bangin2", ":oliver", ":logout", ":koncha", ":nofomo", ":dracula", ":saj", ":madgun", ":mlady", ":working2", ":fatthang", ":shalom", ":feetza", ":11dabs", ":cid", ":education", ":jesuschrist", ":hm2", ":tour", ":hm3", ":hawktuah", ":emet", ":sun", ":denver", ":fishass", ":apeinside", ":neeknap", ":rawrbike", ":turnup", ":dickriding", ":note2", ":spicyshow", ":dancer", ":joebiden", "::hawktuah", ":meatbliss", ":really3", ":vibes2", ":goofin", ":flipfreak", ":rawrfreak", ":cocaine", ":myth", ":ponsgroom", ":itstrue", ":robodog", ":chat", ":urbutt3", ":nice5", ":zamn3", ":betray", ":kippwithit", ":pondering", ":wizard2", ":smugkipps", ":review", ":howle", ":america", ":riri", ":hero", ":eggwheel", ":robobong", ":wwewooo", ":mvp", ":sadclown", ":altf4", ":goodmorning2", ":gm5", ":imsick", ":spicybanana", ":oj", ":kamala", ":fightme3", ":catch", ":letmehit", ":orb2", ":orb3", ":campfirecats", ":dropkick", ":minilla", ":cum3", ":icarenow", ":sillysociety", ":womp", ":hedidwhat", ":dap2", ":thepower", ":febrezeurbutt", ":cruisin", ":wile", ":fuckyouboss", ":fishhass", ":piss2", ":fu3", ":uncuntableforever", ":foulisnotimpressed", ":cybersmonk", ":gotmilk", ":earth", ":dogjump", ":pepperann", ":fishphone", ":samerica", ":furries", ":dreams", ":freerealestate", ":galeforce", ":dipper", ":whyshouldnti", ":fiend", ":judgementday", ":cheese2", ":thanks", ":mashing", ":otto", ":flcl2", ":otto2", ":gun8", ":salt", ":snatch", ":robomovie", ":high5", ":rabbi", ":leekspin", ":hopelesscreature", ":shocked3", ":smirk3", ":rawr4", ":laladance", ":urbuttisfrozen", ":itsperfect", ":what7", ":click2", ":click", ":crip", ":yapping", ":hairflip3", ":wow7", ":special", ":pepejamband", ":jmoney2", ":porter", ":nou3", ":hyb4", ":hyb5", ":widecobra", ":widercobra", ":dickbros", ":yeehawbros", ":crip2", ":appleman", ":camera", ":snack", ":zap", ":morbin", ":nomz", ":tubgirl4", ":supernut", ":madpete2", ":fpsdoug", ":adultcontent", ":methcat", ":dance62", ":tacticool", ":itshappening", ":both", ":smooch", ":tiddies", ":ballseams", ":thinking2", ":cagelaugh", ":shawty", ":drift", ":hankbutt", ":gandalf2", ":sonic3", ":coup", ":kermitshow", ":sonic4", ":sonic5", ":deflated", ":sonic6", ":jumanji", ":knife2", ":fireeyes", ":icu2", ":tarnation6", ":nervousclap", ":perfection", ":mulan", ":gmork", ":huh4", ":poor", ":pptwerk", ":kakegurui", ":dennys", ":imgonna4", ":imgonnasayit", ":trapped", ":hecant", ":time", ":wacky", ":n", "::gm4", ":boobs", ":fishass3", ":acting", ":haitin", ":hug", ":hug4", ":gooned", ":neat2", ":amine"];
  return gifNames.filter(name => name.startsWith(prefix));
}

function displaySuggestions(suggestions, targetElement) {
  let popup = document.getElementById('gif-suggestions-popup');
  if (!popup) {
    popup = document.createElement('div');
    popup.id = 'gif-suggestions-popup';
    popup.style.position = 'absolute';
    popup.style.border = '1px solid #ccc';
    popup.style.backgroundColor = '#fff';
    popup.style.zIndex = '1000';
    document.body.appendChild(popup);
  }

  // Position the popup below the chat input
  const rect = targetElement.getBoundingClientRect();
  popup.style.left = `${rect.left}px`;
  popup.style.top = `${rect.bottom + window.scrollY}px`;

  // Populate the popup with suggestions
  popup.innerHTML = suggestions.map(s => `<div>${s}</div>`).join('');

  // Add click event to each suggestion
  popup.childNodes.forEach(child => {
    child.addEventListener('click', function () {
      const currentValue = targetElement.value;
      targetElement.value = currentValue.replace(/:[^ ]*$/, this.textContent);
      removeSuggestionsPopup();
    });
  });
}

function removeSuggestionsPopup() {
  const popup = document.getElementById('gif-suggestions-popup');
  if (popup) {
    popup.remove();
  }
}
